# -*- coding: utf-8 -*-
"""
Profile: http://hl7.org/fhir/StructureDefinition/SubstanceNucleicAcid
Release: R5
Version: 5.0.0
Build ID: 2aecd53
Last updated: 2023-03-26T15:21:02.749+11:00
"""
import typing

from pydantic import Field

from . import backboneelement, domainresource, fhirtypes


class SubstanceNucleicAcid(domainresource.DomainResource):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    Nucleic acids are defined by three distinct elements: the base, sugar and
    linkage. Individual substance/moiety IDs will be created for each of these
    elements. The nucleotide sequence will be always entered in the 5’-3’
    direction.
    """

    __resource_type__ = "SubstanceNucleicAcid"

    areaOfHybridisation: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="areaOfHybridisation",
        title=(
            "The area of hybridisation shall be described if applicable for double "
            "stranded RNA or DNA. The number associated with the subunit followed "
            "by the number associated to the residue shall be specified in "
            "increasing order. The underscore \u201c\u201d shall be used as separator as "
            "follows: \u201cSubunitnumber Residue\u201d"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    areaOfHybridisation__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None,
        alias="_areaOfHybridisation",
        title="Extension field for ``areaOfHybridisation``.",
    )

    numberOfSubunits: fhirtypes.IntegerType = Field(  # type: ignore
        None,
        alias="numberOfSubunits",
        title=(
            "The number of linear sequences of nucleotides linked through "
            "phosphodiester bonds shall be described. Subunits would be strands of "
            "nucleic acids that are tightly associated typically through Watson-"
            "Crick base pairing. NOTE: If not specified in the reference source, "
            "the assumption is that there is 1 subunit"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    numberOfSubunits__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None,
        alias="_numberOfSubunits",
        title="Extension field for ``numberOfSubunits``.",
    )

    oligoNucleotideType: fhirtypes.CodeableConceptType = Field(  # type: ignore
        None,
        alias="oligoNucleotideType",
        title="(TBC)",
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    sequenceType: fhirtypes.CodeableConceptType = Field(  # type: ignore
        None,
        alias="sequenceType",
        title=(
            "The type of the sequence shall be specified based on a controlled "
            "vocabulary"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    subunit: typing.List[fhirtypes.SubstanceNucleicAcidSubunitType] = Field(  # type: ignore
        None,
        alias="subunit",
        title=(
            "Subunits are listed in order of decreasing length; sequences of the "
            "same length will be ordered by molecular weight; subunits that have "
            "identical sequences will be repeated multiple times"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``SubstanceNucleicAcid`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "meta",
            "implicitRules",
            "language",
            "text",
            "contained",
            "extension",
            "modifierExtension",
            "sequenceType",
            "numberOfSubunits",
            "areaOfHybridisation",
            "oligoNucleotideType",
            "subunit",
        ]


class SubstanceNucleicAcidSubunit(backboneelement.BackboneElement):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    Subunits are listed in order of decreasing length; sequences of the same
    length will be ordered by molecular weight; subunits that have identical
    sequences will be repeated multiple times.
    """

    __resource_type__ = "SubstanceNucleicAcidSubunit"

    fivePrime: fhirtypes.CodeableConceptType = Field(  # type: ignore
        None,
        alias="fivePrime",
        title=(
            "The nucleotide present at the 5\u2019 terminal shall be specified based on "
            "a controlled vocabulary. Since the sequence is represented from the 5'"
            " to the 3' end, the 5\u2019 prime nucleotide is the letter at the first "
            "position in the sequence. A separate representation would be redundant"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    length: fhirtypes.IntegerType = Field(  # type: ignore
        None,
        alias="length",
        title="The length of the sequence shall be captured",
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    length__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_length", title="Extension field for ``length``."
    )

    linkage: typing.List[fhirtypes.SubstanceNucleicAcidSubunitLinkageType] = Field(  # type: ignore
        None,
        alias="linkage",
        title="The linkages between sugar residues will also be captured",
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    sequence: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="sequence",
        title=(
            "Actual nucleotide sequence notation from 5' to 3' end using standard "
            "single letter codes. In addition to the base sequence, sugar and type "
            "of phosphate or non-phosphate linkage should also be captured"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    sequence__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_sequence", title="Extension field for ``sequence``."
    )

    sequenceAttachment: fhirtypes.AttachmentType = Field(  # type: ignore
        None,
        alias="sequenceAttachment",
        title="(TBC)",
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    subunit: fhirtypes.IntegerType = Field(  # type: ignore
        None,
        alias="subunit",
        title=(
            "Index of linear sequences of nucleic acids in order of decreasing "
            "length. Sequences of the same length will be ordered by molecular "
            "weight. Subunits that have identical sequences will be repeated and "
            "have sequential subscripts"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    subunit__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_subunit", title="Extension field for ``subunit``."
    )

    sugar: typing.List[fhirtypes.SubstanceNucleicAcidSubunitSugarType] = Field(  # type: ignore
        None,
        alias="sugar",
        title="5.3.6.8.1 Sugar ID (Mandatory)",
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    threePrime: fhirtypes.CodeableConceptType = Field(  # type: ignore
        None,
        alias="threePrime",
        title=(
            "The nucleotide present at the 3\u2019 terminal shall be specified based on "
            "a controlled vocabulary. Since the sequence is represented from the 5'"
            " to the 3' end, the 5\u2019 prime nucleotide is the letter at the last "
            "position in the sequence. A separate representation would be redundant"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``SubstanceNucleicAcidSubunit`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "extension",
            "modifierExtension",
            "subunit",
            "sequence",
            "length",
            "sequenceAttachment",
            "fivePrime",
            "threePrime",
            "linkage",
            "sugar",
        ]


class SubstanceNucleicAcidSubunitLinkage(backboneelement.BackboneElement):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    The linkages between sugar residues will also be captured.
    """

    __resource_type__ = "SubstanceNucleicAcidSubunitLinkage"

    connectivity: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="connectivity",
        title=(
            "The entity that links the sugar residues together should also be "
            "captured for nearly all naturally occurring nucleic acid the linkage "
            "is a phosphate group. For many synthetic oligonucleotides "
            "phosphorothioate linkages are often seen. Linkage connectivity is "
            "assumed to be 3\u2019-5\u2019. If the linkage is either 3\u2019-3\u2019 or 5\u2019-5\u2019 this "
            "should be specified"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    connectivity__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_connectivity", title="Extension field for ``connectivity``."
    )

    identifier: fhirtypes.IdentifierType = Field(  # type: ignore
        None,
        alias="identifier",
        title="Each linkage will be registered as a fragment and have an ID",
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    name: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="name",
        title=(
            "Each linkage will be registered as a fragment and have at least one "
            "name. A single name shall be assigned to each linkage"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    name__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_name", title="Extension field for ``name``."
    )

    residueSite: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="residueSite",
        title="Residues shall be captured as described in 5.3.6.8.3",
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    residueSite__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_residueSite", title="Extension field for ``residueSite``."
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``SubstanceNucleicAcidSubunitLinkage`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "extension",
            "modifierExtension",
            "connectivity",
            "identifier",
            "name",
            "residueSite",
        ]


class SubstanceNucleicAcidSubunitSugar(backboneelement.BackboneElement):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    5.3.6.8.1 Sugar ID (Mandatory).
    """

    __resource_type__ = "SubstanceNucleicAcidSubunitSugar"

    identifier: fhirtypes.IdentifierType = Field(  # type: ignore
        None,
        alias="identifier",
        title=(
            "The Substance ID of the sugar or sugar-like component that make up the"
            " nucleotide"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    name: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="name",
        title=(
            "The name of the sugar or sugar-like component that make up the "
            "nucleotide"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    name__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_name", title="Extension field for ``name``."
    )

    residueSite: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="residueSite",
        title=(
            "The residues that contain a given sugar will be captured. The order of"
            " given residues will be captured in the 5\u2018-3\u2018direction consistent with"
            " the base sequences listed above"
        ),
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )
    residueSite__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_residueSite", title="Extension field for ``residueSite``."
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``SubstanceNucleicAcidSubunitSugar`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "extension",
            "modifierExtension",
            "identifier",
            "name",
            "residueSite",
        ]



# -*- coding: utf-8 -*-
"""
Profile: http://hl7.org/fhir/StructureDefinition/ObservationDefinition
Release: R4B
Version: 4.3.0
Build ID: c475c22
Last updated: 2022-05-28T12:47:40.239+10:00
"""
import typing

from pydantic import Field

from . import backboneelement, domainresource, fhirtypes


class ObservationDefinition(domainresource.DomainResource):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    Definition of an observation.
    Set of definitional characteristics for a kind of observation or
    measurement produced or consumed by an orderable health care service.
    """

    __resource_type__ = "ObservationDefinition"

    abnormalCodedValueSet: fhirtypes.ReferenceType = Field(  # type: ignore
        None,
        alias="abnormalCodedValueSet",
        title=(
            "Value set of abnormal coded values for the observations conforming to "
            "this ObservationDefinition"
        ),
        description=(
            "The set of abnormal coded results for the observation conforming to "
            "this ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["ValueSet"],
        },
    )

    category: typing.List[fhirtypes.CodeableConceptType] = Field(  # type: ignore
        None,
        alias="category",
        title="Category of observation",
        description="A code that classifies the general type of observation.",
        json_schema_extra={
            "element_property": True,
        },
    )

    code: fhirtypes.CodeableConceptType = Field(  # type: ignore
        ...,
        alias="code",
        title="Type of observation (code / type)",
        description=(
            "Describes what will be observed. Sometimes this is called the "
            'observation "name".'
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    criticalCodedValueSet: fhirtypes.ReferenceType = Field(  # type: ignore
        None,
        alias="criticalCodedValueSet",
        title=(
            "Value set of critical coded values for the observations conforming to "
            "this ObservationDefinition"
        ),
        description=(
            "The set of critical coded results for the observation conforming to "
            "this ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["ValueSet"],
        },
    )

    identifier: typing.List[fhirtypes.IdentifierType] = Field(  # type: ignore
        None,
        alias="identifier",
        title="Business identifier for this ObservationDefinition instance",
        description="A unique identifier assigned to this ObservationDefinition artifact.",
        json_schema_extra={
            "element_property": True,
        },
    )

    method: fhirtypes.CodeableConceptType = Field(  # type: ignore
        None,
        alias="method",
        title="Method used to produce the observation",
        description="The method or technique used to perform the observation.",
        json_schema_extra={
            "element_property": True,
        },
    )

    multipleResultsAllowed: bool = Field(  # type: ignore
        None,
        alias="multipleResultsAllowed",
        title="Multiple results allowed",
        description=(
            "Multiple results allowed for observations conforming to this "
            "ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    multipleResultsAllowed__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None,
        alias="_multipleResultsAllowed",
        title="Extension field for ``multipleResultsAllowed``.",
    )

    normalCodedValueSet: fhirtypes.ReferenceType = Field(  # type: ignore
        None,
        alias="normalCodedValueSet",
        title=(
            "Value set of normal coded values for the observations conforming to "
            "this ObservationDefinition"
        ),
        description=(
            "The set of normal coded results for the observations conforming to "
            "this ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["ValueSet"],
        },
    )

    permittedDataType: typing.List[typing.Optional[fhirtypes.CodeType]] = Field(  # type: ignore
        None,
        alias="permittedDataType",
        title=(
            "Quantity | CodeableConcept | string | boolean | integer | Range | "
            "Ratio | SampledData | time | dateTime | Period"
        ),
        description=(
            "The data types allowed for the value element of the instance "
            "observations conforming to this ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Enum values can be used in validation,
            # but use in your own responsibilities, read official FHIR documentation.
            "enum_values": [
                "Quantity",
                "CodeableConcept",
                "string",
                "boolean",
                "integer",
                "Range",
                "Ratio",
                "SampledData",
                "time",
                "dateTime",
                "Period",
            ],
        },
    )
    permittedDataType__ext: typing.List[typing.Union[fhirtypes.FHIRPrimitiveExtensionType, None]] = Field(  # type: ignore
        None,
        alias="_permittedDataType",
        title="Extension field for ``permittedDataType``.",
    )

    preferredReportName: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="preferredReportName",
        title="Preferred report name",
        description=(
            "The preferred name to be used when reporting the results of "
            "observations conforming to this ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    preferredReportName__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None,
        alias="_preferredReportName",
        title="Extension field for ``preferredReportName``.",
    )

    qualifiedInterval: typing.List[fhirtypes.ObservationDefinitionQualifiedIntervalType] = Field(  # type: ignore
        None,
        alias="qualifiedInterval",
        title="Qualified range for continuous and ordinal observation results",
        description=(
            "Multiple  ranges of results qualified by different contexts for "
            "ordinal or continuous observations conforming to this "
            "ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    quantitativeDetails: fhirtypes.ObservationDefinitionQuantitativeDetailsType = Field(  # type: ignore
        None,
        alias="quantitativeDetails",
        title="Characteristics of quantitative results",
        description="Characteristics for quantitative results of this observation.",
        json_schema_extra={
            "element_property": True,
        },
    )

    validCodedValueSet: fhirtypes.ReferenceType = Field(  # type: ignore
        None,
        alias="validCodedValueSet",
        title=(
            "Value set of valid coded values for the observations conforming to "
            "this ObservationDefinition"
        ),
        description=(
            "The set of valid coded results for the observations  conforming to "
            "this ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["ValueSet"],
        },
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``ObservationDefinition`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "meta",
            "implicitRules",
            "language",
            "text",
            "contained",
            "extension",
            "modifierExtension",
            "category",
            "code",
            "identifier",
            "permittedDataType",
            "multipleResultsAllowed",
            "method",
            "preferredReportName",
            "quantitativeDetails",
            "qualifiedInterval",
            "validCodedValueSet",
            "normalCodedValueSet",
            "abnormalCodedValueSet",
            "criticalCodedValueSet",
        ]


class ObservationDefinitionQualifiedInterval(backboneelement.BackboneElement):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    Qualified range for continuous and ordinal observation results.
    Multiple  ranges of results qualified by different contexts for ordinal or
    continuous observations conforming to this ObservationDefinition.
    """

    __resource_type__ = "ObservationDefinitionQualifiedInterval"

    age: fhirtypes.RangeType = Field(  # type: ignore
        None,
        alias="age",
        title="Applicable age range, if relevant",
        description=(
            "The age at which this reference range is applicable. This is a "
            "neonatal age (e.g. number of weeks at term) if the meaning says so."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    appliesTo: typing.List[fhirtypes.CodeableConceptType] = Field(  # type: ignore
        None,
        alias="appliesTo",
        title="Targetted population of the range",
        description=(
            "Codes to indicate the target population this reference range applies "
            "to."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    category: fhirtypes.CodeType = Field(  # type: ignore
        None,
        alias="category",
        title="reference | critical | absolute",
        description=(
            "The category of interval of values for continuous or ordinal "
            "observations conforming to this ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Enum values can be used in validation,
            # but use in your own responsibilities, read official FHIR documentation.
            "enum_values": ["reference", "critical", "absolute"],
        },
    )
    category__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_category", title="Extension field for ``category``."
    )

    condition: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="condition",
        title="Condition associated with the reference range",
        description="Text based condition for which the reference range is valid.",
        json_schema_extra={
            "element_property": True,
        },
    )
    condition__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_condition", title="Extension field for ``condition``."
    )

    context: fhirtypes.CodeableConceptType = Field(  # type: ignore
        None,
        alias="context",
        title="Range context qualifier",
        description=(
            "Codes to indicate the health context the range applies to. For "
            "example, the normal or therapeutic range."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    gender: fhirtypes.CodeType = Field(  # type: ignore
        None,
        alias="gender",
        title="male | female | other | unknown",
        description="Sex of the population the range applies to.",
        json_schema_extra={
            "element_property": True,
            # note: Enum values can be used in validation,
            # but use in your own responsibilities, read official FHIR documentation.
            "enum_values": ["male", "female", "other", "unknown"],
        },
    )
    gender__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_gender", title="Extension field for ``gender``."
    )

    gestationalAge: fhirtypes.RangeType = Field(  # type: ignore
        None,
        alias="gestationalAge",
        title="Applicable gestational age range, if relevant",
        description=(
            "The gestational age to which this reference range is applicable, in "
            "the context of pregnancy."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    range: fhirtypes.RangeType = Field(  # type: ignore
        None,
        alias="range",
        title="The interval itself, for continuous or ordinal observations",
        description=(
            "The low and high values determining the interval. There may be only "
            "one of the two."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``ObservationDefinitionQualifiedInterval`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "extension",
            "modifierExtension",
            "category",
            "range",
            "context",
            "appliesTo",
            "gender",
            "age",
            "gestationalAge",
            "condition",
        ]


class ObservationDefinitionQuantitativeDetails(backboneelement.BackboneElement):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    Characteristics of quantitative results.
    Characteristics for quantitative results of this observation.
    """

    __resource_type__ = "ObservationDefinitionQuantitativeDetails"

    conversionFactor: fhirtypes.DecimalType = Field(  # type: ignore
        None,
        alias="conversionFactor",
        title="SI to Customary unit conversion factor",
        description=(
            "Factor for converting value expressed with SI unit to value expressed "
            "with customary unit."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    conversionFactor__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None,
        alias="_conversionFactor",
        title="Extension field for ``conversionFactor``.",
    )

    customaryUnit: fhirtypes.CodeableConceptType = Field(  # type: ignore
        None,
        alias="customaryUnit",
        title="Customary unit for quantitative results",
        description=(
            "Customary unit used to report quantitative results of observations "
            "conforming to this ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    decimalPrecision: fhirtypes.IntegerType = Field(  # type: ignore
        None,
        alias="decimalPrecision",
        title="Decimal precision of observation quantitative results",
        description=(
            "Number of digits after decimal separator when the results of such "
            "observations are of type Quantity."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    decimalPrecision__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None,
        alias="_decimalPrecision",
        title="Extension field for ``decimalPrecision``.",
    )

    unit: fhirtypes.CodeableConceptType = Field(  # type: ignore
        None,
        alias="unit",
        title="SI unit for quantitative results",
        description=(
            "SI unit used to report quantitative results of observations conforming"
            " to this ObservationDefinition."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``ObservationDefinitionQuantitativeDetails`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "extension",
            "modifierExtension",
            "customaryUnit",
            "unit",
            "conversionFactor",
            "decimalPrecision",
        ]



from __future__ import annotations as _annotations

from fhir_core.types import (
    Base64BinaryType,
    BooleanType,
    CanonicalType,
    CodeType,
    DateTimeType,
    DateType,
    DecimalType,
    IdType,
    InstantType,
    Integer64Type,
    IntegerType,
    MarkdownType,
    OidType,
    PositiveIntType,
    StringType,
    TimeType,
    UnsignedIntType,
    UriType,
    UrlType,
    UuidType,
    XhtmlType,
    create_fhir_element_or_resource_type,
    create_fhir_type,
)

__author__ = "Md Nazrul Islam"
__email__ = "email2nazrul@gmail.com"


FHIRPrimitiveExtensionType = create_fhir_type(
    "FHIRPrimitiveExtensionType",
    "fhir.resources.STU3.fhirprimitiveextension.FHIRPrimitiveExtension",
)

ElementType = create_fhir_element_or_resource_type(
    "ElementType", "fhir.resources.STU3.element.Element"
)

ResourceType = create_fhir_element_or_resource_type(
    "ResourceType", "fhir.resources.STU3.resource.Resource"
)
AccountType = create_fhir_type("AccountType", "fhir.resources.STU3.account.Account")

AccountCoverageType = create_fhir_type(
    "AccountCoverageType", "fhir.resources.STU3.account.AccountCoverage"
)

AccountGuarantorType = create_fhir_type(
    "AccountGuarantorType", "fhir.resources.STU3.account.AccountGuarantor"
)

ActivityDefinitionType = create_fhir_type(
    "ActivityDefinitionType",
    "fhir.resources.STU3.activitydefinition.ActivityDefinition",
)

ActivityDefinitionDynamicValueType = create_fhir_type(
    "ActivityDefinitionDynamicValueType",
    "fhir.resources.STU3.activitydefinition.ActivityDefinitionDynamicValue",
)

ActivityDefinitionParticipantType = create_fhir_type(
    "ActivityDefinitionParticipantType",
    "fhir.resources.STU3.activitydefinition.ActivityDefinitionParticipant",
)

AddressType = create_fhir_type("AddressType", "fhir.resources.STU3.address.Address")

AdverseEventType = create_fhir_type(
    "AdverseEventType", "fhir.resources.STU3.adverseevent.AdverseEvent"
)

AdverseEventSuspectEntityType = create_fhir_type(
    "AdverseEventSuspectEntityType",
    "fhir.resources.STU3.adverseevent.AdverseEventSuspectEntity",
)

AgeType = create_fhir_type("AgeType", "fhir.resources.STU3.age.Age")

AllergyIntoleranceType = create_fhir_type(
    "AllergyIntoleranceType",
    "fhir.resources.STU3.allergyintolerance.AllergyIntolerance",
)

AllergyIntoleranceReactionType = create_fhir_type(
    "AllergyIntoleranceReactionType",
    "fhir.resources.STU3.allergyintolerance.AllergyIntoleranceReaction",
)

AnnotationType = create_fhir_type(
    "AnnotationType", "fhir.resources.STU3.annotation.Annotation"
)

AppointmentType = create_fhir_type(
    "AppointmentType", "fhir.resources.STU3.appointment.Appointment"
)

AppointmentParticipantType = create_fhir_type(
    "AppointmentParticipantType",
    "fhir.resources.STU3.appointment.AppointmentParticipant",
)

AppointmentResponseType = create_fhir_type(
    "AppointmentResponseType",
    "fhir.resources.STU3.appointmentresponse.AppointmentResponse",
)

AttachmentType = create_fhir_type(
    "AttachmentType", "fhir.resources.STU3.attachment.Attachment"
)

AuditEventType = create_fhir_type(
    "AuditEventType", "fhir.resources.STU3.auditevent.AuditEvent"
)

AuditEventAgentType = create_fhir_type(
    "AuditEventAgentType", "fhir.resources.STU3.auditevent.AuditEventAgent"
)

AuditEventAgentNetworkType = create_fhir_type(
    "AuditEventAgentNetworkType",
    "fhir.resources.STU3.auditevent.AuditEventAgentNetwork",
)

AuditEventEntityType = create_fhir_type(
    "AuditEventEntityType", "fhir.resources.STU3.auditevent.AuditEventEntity"
)

AuditEventEntityDetailType = create_fhir_type(
    "AuditEventEntityDetailType",
    "fhir.resources.STU3.auditevent.AuditEventEntityDetail",
)

AuditEventSourceType = create_fhir_type(
    "AuditEventSourceType", "fhir.resources.STU3.auditevent.AuditEventSource"
)

BackboneElementType = create_fhir_type(
    "BackboneElementType", "fhir.resources.STU3.backboneelement.BackboneElement"
)

BasicType = create_fhir_type("BasicType", "fhir.resources.STU3.basic.Basic")

BinaryType = create_fhir_type("BinaryType", "fhir.resources.STU3.binary.Binary")

BodySiteType = create_fhir_type("BodySiteType", "fhir.resources.STU3.bodysite.BodySite")

BundleType = create_fhir_type("BundleType", "fhir.resources.STU3.bundle.Bundle")

BundleEntryType = create_fhir_type(
    "BundleEntryType", "fhir.resources.STU3.bundle.BundleEntry"
)

BundleEntryRequestType = create_fhir_type(
    "BundleEntryRequestType", "fhir.resources.STU3.bundle.BundleEntryRequest"
)

BundleEntryResponseType = create_fhir_type(
    "BundleEntryResponseType", "fhir.resources.STU3.bundle.BundleEntryResponse"
)

BundleEntrySearchType = create_fhir_type(
    "BundleEntrySearchType", "fhir.resources.STU3.bundle.BundleEntrySearch"
)

BundleLinkType = create_fhir_type(
    "BundleLinkType", "fhir.resources.STU3.bundle.BundleLink"
)

CapabilityStatementType = create_fhir_type(
    "CapabilityStatementType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatement",
)

CapabilityStatementDocumentType = create_fhir_type(
    "CapabilityStatementDocumentType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementDocument",
)

CapabilityStatementImplementationType = create_fhir_type(
    "CapabilityStatementImplementationType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementImplementation",
)

CapabilityStatementMessagingType = create_fhir_type(
    "CapabilityStatementMessagingType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementMessaging",
)

CapabilityStatementMessagingEndpointType = create_fhir_type(
    "CapabilityStatementMessagingEndpointType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementMessagingEndpoint",
)

CapabilityStatementMessagingEventType = create_fhir_type(
    "CapabilityStatementMessagingEventType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementMessagingEvent",
)

CapabilityStatementMessagingSupportedMessageType = create_fhir_type(
    "CapabilityStatementMessagingSupportedMessageType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementMessagingSupportedMessage",
)

CapabilityStatementRestType = create_fhir_type(
    "CapabilityStatementRestType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementRest",
)

CapabilityStatementRestInteractionType = create_fhir_type(
    "CapabilityStatementRestInteractionType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementRestInteraction",
)

CapabilityStatementRestOperationType = create_fhir_type(
    "CapabilityStatementRestOperationType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementRestOperation",
)

CapabilityStatementRestResourceType = create_fhir_type(
    "CapabilityStatementRestResourceType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementRestResource",
)

CapabilityStatementRestResourceInteractionType = create_fhir_type(
    "CapabilityStatementRestResourceInteractionType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementRestResourceInteraction",
)

CapabilityStatementRestResourceSearchParamType = create_fhir_type(
    "CapabilityStatementRestResourceSearchParamType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementRestResourceSearchParam",
)

CapabilityStatementRestSecurityType = create_fhir_type(
    "CapabilityStatementRestSecurityType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementRestSecurity",
)

CapabilityStatementRestSecurityCertificateType = create_fhir_type(
    "CapabilityStatementRestSecurityCertificateType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementRestSecurityCertificate",
)

CapabilityStatementSoftwareType = create_fhir_type(
    "CapabilityStatementSoftwareType",
    "fhir.resources.STU3.capabilitystatement.CapabilityStatementSoftware",
)

CarePlanType = create_fhir_type("CarePlanType", "fhir.resources.STU3.careplan.CarePlan")

CarePlanActivityType = create_fhir_type(
    "CarePlanActivityType", "fhir.resources.STU3.careplan.CarePlanActivity"
)

CarePlanActivityDetailType = create_fhir_type(
    "CarePlanActivityDetailType", "fhir.resources.STU3.careplan.CarePlanActivityDetail"
)

CareTeamType = create_fhir_type("CareTeamType", "fhir.resources.STU3.careteam.CareTeam")

CareTeamParticipantType = create_fhir_type(
    "CareTeamParticipantType", "fhir.resources.STU3.careteam.CareTeamParticipant"
)

ChargeItemType = create_fhir_type(
    "ChargeItemType", "fhir.resources.STU3.chargeitem.ChargeItem"
)

ChargeItemParticipantType = create_fhir_type(
    "ChargeItemParticipantType", "fhir.resources.STU3.chargeitem.ChargeItemParticipant"
)

ClaimType = create_fhir_type("ClaimType", "fhir.resources.STU3.claim.Claim")

ClaimAccidentType = create_fhir_type(
    "ClaimAccidentType", "fhir.resources.STU3.claim.ClaimAccident"
)

ClaimCareTeamType = create_fhir_type(
    "ClaimCareTeamType", "fhir.resources.STU3.claim.ClaimCareTeam"
)

ClaimDiagnosisType = create_fhir_type(
    "ClaimDiagnosisType", "fhir.resources.STU3.claim.ClaimDiagnosis"
)

ClaimInformationType = create_fhir_type(
    "ClaimInformationType", "fhir.resources.STU3.claim.ClaimInformation"
)

ClaimInsuranceType = create_fhir_type(
    "ClaimInsuranceType", "fhir.resources.STU3.claim.ClaimInsurance"
)

ClaimItemType = create_fhir_type("ClaimItemType", "fhir.resources.STU3.claim.ClaimItem")

ClaimItemDetailType = create_fhir_type(
    "ClaimItemDetailType", "fhir.resources.STU3.claim.ClaimItemDetail"
)

ClaimItemDetailSubDetailType = create_fhir_type(
    "ClaimItemDetailSubDetailType", "fhir.resources.STU3.claim.ClaimItemDetailSubDetail"
)

ClaimPayeeType = create_fhir_type(
    "ClaimPayeeType", "fhir.resources.STU3.claim.ClaimPayee"
)

ClaimProcedureType = create_fhir_type(
    "ClaimProcedureType", "fhir.resources.STU3.claim.ClaimProcedure"
)

ClaimRelatedType = create_fhir_type(
    "ClaimRelatedType", "fhir.resources.STU3.claim.ClaimRelated"
)

ClaimResponseType = create_fhir_type(
    "ClaimResponseType", "fhir.resources.STU3.claimresponse.ClaimResponse"
)

ClaimResponseAddItemType = create_fhir_type(
    "ClaimResponseAddItemType", "fhir.resources.STU3.claimresponse.ClaimResponseAddItem"
)

ClaimResponseAddItemDetailType = create_fhir_type(
    "ClaimResponseAddItemDetailType",
    "fhir.resources.STU3.claimresponse.ClaimResponseAddItemDetail",
)

ClaimResponseErrorType = create_fhir_type(
    "ClaimResponseErrorType", "fhir.resources.STU3.claimresponse.ClaimResponseError"
)

ClaimResponseInsuranceType = create_fhir_type(
    "ClaimResponseInsuranceType",
    "fhir.resources.STU3.claimresponse.ClaimResponseInsurance",
)

ClaimResponseItemType = create_fhir_type(
    "ClaimResponseItemType", "fhir.resources.STU3.claimresponse.ClaimResponseItem"
)

ClaimResponseItemAdjudicationType = create_fhir_type(
    "ClaimResponseItemAdjudicationType",
    "fhir.resources.STU3.claimresponse.ClaimResponseItemAdjudication",
)

ClaimResponseItemDetailType = create_fhir_type(
    "ClaimResponseItemDetailType",
    "fhir.resources.STU3.claimresponse.ClaimResponseItemDetail",
)

ClaimResponseItemDetailSubDetailType = create_fhir_type(
    "ClaimResponseItemDetailSubDetailType",
    "fhir.resources.STU3.claimresponse.ClaimResponseItemDetailSubDetail",
)

ClaimResponsePaymentType = create_fhir_type(
    "ClaimResponsePaymentType", "fhir.resources.STU3.claimresponse.ClaimResponsePayment"
)

ClaimResponseProcessNoteType = create_fhir_type(
    "ClaimResponseProcessNoteType",
    "fhir.resources.STU3.claimresponse.ClaimResponseProcessNote",
)

ClinicalImpressionType = create_fhir_type(
    "ClinicalImpressionType",
    "fhir.resources.STU3.clinicalimpression.ClinicalImpression",
)

ClinicalImpressionFindingType = create_fhir_type(
    "ClinicalImpressionFindingType",
    "fhir.resources.STU3.clinicalimpression.ClinicalImpressionFinding",
)

ClinicalImpressionInvestigationType = create_fhir_type(
    "ClinicalImpressionInvestigationType",
    "fhir.resources.STU3.clinicalimpression.ClinicalImpressionInvestigation",
)

CodeSystemType = create_fhir_type(
    "CodeSystemType", "fhir.resources.STU3.codesystem.CodeSystem"
)

CodeSystemConceptType = create_fhir_type(
    "CodeSystemConceptType", "fhir.resources.STU3.codesystem.CodeSystemConcept"
)

CodeSystemConceptDesignationType = create_fhir_type(
    "CodeSystemConceptDesignationType",
    "fhir.resources.STU3.codesystem.CodeSystemConceptDesignation",
)

CodeSystemConceptPropertyType = create_fhir_type(
    "CodeSystemConceptPropertyType",
    "fhir.resources.STU3.codesystem.CodeSystemConceptProperty",
)

CodeSystemFilterType = create_fhir_type(
    "CodeSystemFilterType", "fhir.resources.STU3.codesystem.CodeSystemFilter"
)

CodeSystemPropertyType = create_fhir_type(
    "CodeSystemPropertyType", "fhir.resources.STU3.codesystem.CodeSystemProperty"
)

CodeableConceptType = create_fhir_type(
    "CodeableConceptType", "fhir.resources.STU3.codeableconcept.CodeableConcept"
)

CodingType = create_fhir_type("CodingType", "fhir.resources.STU3.coding.Coding")

CommunicationType = create_fhir_type(
    "CommunicationType", "fhir.resources.STU3.communication.Communication"
)

CommunicationPayloadType = create_fhir_type(
    "CommunicationPayloadType", "fhir.resources.STU3.communication.CommunicationPayload"
)

CommunicationRequestType = create_fhir_type(
    "CommunicationRequestType",
    "fhir.resources.STU3.communicationrequest.CommunicationRequest",
)

CommunicationRequestPayloadType = create_fhir_type(
    "CommunicationRequestPayloadType",
    "fhir.resources.STU3.communicationrequest.CommunicationRequestPayload",
)

CommunicationRequestRequesterType = create_fhir_type(
    "CommunicationRequestRequesterType",
    "fhir.resources.STU3.communicationrequest.CommunicationRequestRequester",
)

CompartmentDefinitionType = create_fhir_type(
    "CompartmentDefinitionType",
    "fhir.resources.STU3.compartmentdefinition.CompartmentDefinition",
)

CompartmentDefinitionResourceType = create_fhir_type(
    "CompartmentDefinitionResourceType",
    "fhir.resources.STU3.compartmentdefinition.CompartmentDefinitionResource",
)

CompositionType = create_fhir_type(
    "CompositionType", "fhir.resources.STU3.composition.Composition"
)

CompositionAttesterType = create_fhir_type(
    "CompositionAttesterType", "fhir.resources.STU3.composition.CompositionAttester"
)

CompositionEventType = create_fhir_type(
    "CompositionEventType", "fhir.resources.STU3.composition.CompositionEvent"
)

CompositionRelatesToType = create_fhir_type(
    "CompositionRelatesToType", "fhir.resources.STU3.composition.CompositionRelatesTo"
)

CompositionSectionType = create_fhir_type(
    "CompositionSectionType", "fhir.resources.STU3.composition.CompositionSection"
)

ConceptMapType = create_fhir_type(
    "ConceptMapType", "fhir.resources.STU3.conceptmap.ConceptMap"
)

ConceptMapGroupType = create_fhir_type(
    "ConceptMapGroupType", "fhir.resources.STU3.conceptmap.ConceptMapGroup"
)

ConceptMapGroupElementType = create_fhir_type(
    "ConceptMapGroupElementType",
    "fhir.resources.STU3.conceptmap.ConceptMapGroupElement",
)

ConceptMapGroupElementTargetType = create_fhir_type(
    "ConceptMapGroupElementTargetType",
    "fhir.resources.STU3.conceptmap.ConceptMapGroupElementTarget",
)

ConceptMapGroupElementTargetDependsOnType = create_fhir_type(
    "ConceptMapGroupElementTargetDependsOnType",
    "fhir.resources.STU3.conceptmap.ConceptMapGroupElementTargetDependsOn",
)

ConceptMapGroupUnmappedType = create_fhir_type(
    "ConceptMapGroupUnmappedType",
    "fhir.resources.STU3.conceptmap.ConceptMapGroupUnmapped",
)

ConditionType = create_fhir_type(
    "ConditionType", "fhir.resources.STU3.condition.Condition"
)

ConditionEvidenceType = create_fhir_type(
    "ConditionEvidenceType", "fhir.resources.STU3.condition.ConditionEvidence"
)

ConditionStageType = create_fhir_type(
    "ConditionStageType", "fhir.resources.STU3.condition.ConditionStage"
)

ConsentType = create_fhir_type("ConsentType", "fhir.resources.STU3.consent.Consent")

ConsentActorType = create_fhir_type(
    "ConsentActorType", "fhir.resources.STU3.consent.ConsentActor"
)

ConsentDataType = create_fhir_type(
    "ConsentDataType", "fhir.resources.STU3.consent.ConsentData"
)

ConsentExceptType = create_fhir_type(
    "ConsentExceptType", "fhir.resources.STU3.consent.ConsentExcept"
)

ConsentExceptActorType = create_fhir_type(
    "ConsentExceptActorType", "fhir.resources.STU3.consent.ConsentExceptActor"
)

ConsentExceptDataType = create_fhir_type(
    "ConsentExceptDataType", "fhir.resources.STU3.consent.ConsentExceptData"
)

ConsentPolicyType = create_fhir_type(
    "ConsentPolicyType", "fhir.resources.STU3.consent.ConsentPolicy"
)

ContactDetailType = create_fhir_type(
    "ContactDetailType", "fhir.resources.STU3.contactdetail.ContactDetail"
)

ContactPointType = create_fhir_type(
    "ContactPointType", "fhir.resources.STU3.contactpoint.ContactPoint"
)

ContractType = create_fhir_type("ContractType", "fhir.resources.STU3.contract.Contract")

ContractAgentType = create_fhir_type(
    "ContractAgentType", "fhir.resources.STU3.contract.ContractAgent"
)

ContractFriendlyType = create_fhir_type(
    "ContractFriendlyType", "fhir.resources.STU3.contract.ContractFriendly"
)

ContractLegalType = create_fhir_type(
    "ContractLegalType", "fhir.resources.STU3.contract.ContractLegal"
)

ContractRuleType = create_fhir_type(
    "ContractRuleType", "fhir.resources.STU3.contract.ContractRule"
)

ContractSignerType = create_fhir_type(
    "ContractSignerType", "fhir.resources.STU3.contract.ContractSigner"
)

ContractTermType = create_fhir_type(
    "ContractTermType", "fhir.resources.STU3.contract.ContractTerm"
)

ContractTermAgentType = create_fhir_type(
    "ContractTermAgentType", "fhir.resources.STU3.contract.ContractTermAgent"
)

ContractTermValuedItemType = create_fhir_type(
    "ContractTermValuedItemType", "fhir.resources.STU3.contract.ContractTermValuedItem"
)

ContractValuedItemType = create_fhir_type(
    "ContractValuedItemType", "fhir.resources.STU3.contract.ContractValuedItem"
)

ContributorType = create_fhir_type(
    "ContributorType", "fhir.resources.STU3.contributor.Contributor"
)

CountType = create_fhir_type("CountType", "fhir.resources.STU3.count.Count")

CoverageType = create_fhir_type("CoverageType", "fhir.resources.STU3.coverage.Coverage")

CoverageGroupingType = create_fhir_type(
    "CoverageGroupingType", "fhir.resources.STU3.coverage.CoverageGrouping"
)

DataElementType = create_fhir_type(
    "DataElementType", "fhir.resources.STU3.dataelement.DataElement"
)

DataElementMappingType = create_fhir_type(
    "DataElementMappingType", "fhir.resources.STU3.dataelement.DataElementMapping"
)

DataRequirementType = create_fhir_type(
    "DataRequirementType", "fhir.resources.STU3.datarequirement.DataRequirement"
)

DataRequirementCodeFilterType = create_fhir_type(
    "DataRequirementCodeFilterType",
    "fhir.resources.STU3.datarequirement.DataRequirementCodeFilter",
)

DataRequirementDateFilterType = create_fhir_type(
    "DataRequirementDateFilterType",
    "fhir.resources.STU3.datarequirement.DataRequirementDateFilter",
)

DetectedIssueType = create_fhir_type(
    "DetectedIssueType", "fhir.resources.STU3.detectedissue.DetectedIssue"
)

DetectedIssueMitigationType = create_fhir_type(
    "DetectedIssueMitigationType",
    "fhir.resources.STU3.detectedissue.DetectedIssueMitigation",
)

DeviceType = create_fhir_type("DeviceType", "fhir.resources.STU3.device.Device")

DeviceComponentType = create_fhir_type(
    "DeviceComponentType", "fhir.resources.STU3.devicecomponent.DeviceComponent"
)

DeviceComponentProductionSpecificationType = create_fhir_type(
    "DeviceComponentProductionSpecificationType",
    "fhir.resources.STU3.devicecomponent.DeviceComponentProductionSpecification",
)

DeviceMetricType = create_fhir_type(
    "DeviceMetricType", "fhir.resources.STU3.devicemetric.DeviceMetric"
)

DeviceMetricCalibrationType = create_fhir_type(
    "DeviceMetricCalibrationType",
    "fhir.resources.STU3.devicemetric.DeviceMetricCalibration",
)

DeviceRequestType = create_fhir_type(
    "DeviceRequestType", "fhir.resources.STU3.devicerequest.DeviceRequest"
)

DeviceRequestRequesterType = create_fhir_type(
    "DeviceRequestRequesterType",
    "fhir.resources.STU3.devicerequest.DeviceRequestRequester",
)

DeviceUdiType = create_fhir_type(
    "DeviceUdiType", "fhir.resources.STU3.device.DeviceUdi"
)

DeviceUseStatementType = create_fhir_type(
    "DeviceUseStatementType",
    "fhir.resources.STU3.deviceusestatement.DeviceUseStatement",
)

DiagnosticReportType = create_fhir_type(
    "DiagnosticReportType", "fhir.resources.STU3.diagnosticreport.DiagnosticReport"
)

DiagnosticReportImageType = create_fhir_type(
    "DiagnosticReportImageType",
    "fhir.resources.STU3.diagnosticreport.DiagnosticReportImage",
)

DiagnosticReportPerformerType = create_fhir_type(
    "DiagnosticReportPerformerType",
    "fhir.resources.STU3.diagnosticreport.DiagnosticReportPerformer",
)

DistanceType = create_fhir_type("DistanceType", "fhir.resources.STU3.distance.Distance")

DocumentManifestType = create_fhir_type(
    "DocumentManifestType", "fhir.resources.STU3.documentmanifest.DocumentManifest"
)

DocumentManifestContentType = create_fhir_type(
    "DocumentManifestContentType",
    "fhir.resources.STU3.documentmanifest.DocumentManifestContent",
)

DocumentManifestRelatedType = create_fhir_type(
    "DocumentManifestRelatedType",
    "fhir.resources.STU3.documentmanifest.DocumentManifestRelated",
)

DocumentReferenceType = create_fhir_type(
    "DocumentReferenceType", "fhir.resources.STU3.documentreference.DocumentReference"
)

DocumentReferenceContentType = create_fhir_type(
    "DocumentReferenceContentType",
    "fhir.resources.STU3.documentreference.DocumentReferenceContent",
)

DocumentReferenceContextType = create_fhir_type(
    "DocumentReferenceContextType",
    "fhir.resources.STU3.documentreference.DocumentReferenceContext",
)

DocumentReferenceContextRelatedType = create_fhir_type(
    "DocumentReferenceContextRelatedType",
    "fhir.resources.STU3.documentreference.DocumentReferenceContextRelated",
)

DocumentReferenceRelatesToType = create_fhir_type(
    "DocumentReferenceRelatesToType",
    "fhir.resources.STU3.documentreference.DocumentReferenceRelatesTo",
)

DomainResourceType = create_fhir_type(
    "DomainResourceType", "fhir.resources.STU3.domainresource.DomainResource"
)

DosageType = create_fhir_type("DosageType", "fhir.resources.STU3.dosage.Dosage")

DurationType = create_fhir_type("DurationType", "fhir.resources.STU3.duration.Duration")

ElementDefinitionType = create_fhir_type(
    "ElementDefinitionType", "fhir.resources.STU3.elementdefinition.ElementDefinition"
)

ElementDefinitionBaseType = create_fhir_type(
    "ElementDefinitionBaseType",
    "fhir.resources.STU3.elementdefinition.ElementDefinitionBase",
)

ElementDefinitionBindingType = create_fhir_type(
    "ElementDefinitionBindingType",
    "fhir.resources.STU3.elementdefinition.ElementDefinitionBinding",
)

ElementDefinitionConstraintType = create_fhir_type(
    "ElementDefinitionConstraintType",
    "fhir.resources.STU3.elementdefinition.ElementDefinitionConstraint",
)

ElementDefinitionExampleType = create_fhir_type(
    "ElementDefinitionExampleType",
    "fhir.resources.STU3.elementdefinition.ElementDefinitionExample",
)

ElementDefinitionMappingType = create_fhir_type(
    "ElementDefinitionMappingType",
    "fhir.resources.STU3.elementdefinition.ElementDefinitionMapping",
)

ElementDefinitionSlicingType = create_fhir_type(
    "ElementDefinitionSlicingType",
    "fhir.resources.STU3.elementdefinition.ElementDefinitionSlicing",
)

ElementDefinitionSlicingDiscriminatorType = create_fhir_type(
    "ElementDefinitionSlicingDiscriminatorType",
    "fhir.resources.STU3.elementdefinition.ElementDefinitionSlicingDiscriminator",
)

ElementDefinitionTypeType = create_fhir_type(
    "ElementDefinitionTypeType",
    "fhir.resources.STU3.elementdefinition.ElementDefinitionType",
)

EligibilityRequestType = create_fhir_type(
    "EligibilityRequestType",
    "fhir.resources.STU3.eligibilityrequest.EligibilityRequest",
)

EligibilityResponseType = create_fhir_type(
    "EligibilityResponseType",
    "fhir.resources.STU3.eligibilityresponse.EligibilityResponse",
)

EligibilityResponseErrorType = create_fhir_type(
    "EligibilityResponseErrorType",
    "fhir.resources.STU3.eligibilityresponse.EligibilityResponseError",
)

EligibilityResponseInsuranceType = create_fhir_type(
    "EligibilityResponseInsuranceType",
    "fhir.resources.STU3.eligibilityresponse.EligibilityResponseInsurance",
)

EligibilityResponseInsuranceBenefitBalanceType = create_fhir_type(
    "EligibilityResponseInsuranceBenefitBalanceType",
    "fhir.resources.STU3.eligibilityresponse.EligibilityResponseInsuranceBenefitBalance",
)

EligibilityResponseInsuranceBenefitBalanceFinancialType = create_fhir_type(
    "EligibilityResponseInsuranceBenefitBalanceFinancialType",
    "fhir.resources.STU3.eligibilityresponse.EligibilityResponseInsuranceBenefitBalanceFinancial",
)

EncounterType = create_fhir_type(
    "EncounterType", "fhir.resources.STU3.encounter.Encounter"
)

EncounterClassHistoryType = create_fhir_type(
    "EncounterClassHistoryType", "fhir.resources.STU3.encounter.EncounterClassHistory"
)

EncounterDiagnosisType = create_fhir_type(
    "EncounterDiagnosisType", "fhir.resources.STU3.encounter.EncounterDiagnosis"
)

EncounterHospitalizationType = create_fhir_type(
    "EncounterHospitalizationType",
    "fhir.resources.STU3.encounter.EncounterHospitalization",
)

EncounterLocationType = create_fhir_type(
    "EncounterLocationType", "fhir.resources.STU3.encounter.EncounterLocation"
)

EncounterParticipantType = create_fhir_type(
    "EncounterParticipantType", "fhir.resources.STU3.encounter.EncounterParticipant"
)

EncounterStatusHistoryType = create_fhir_type(
    "EncounterStatusHistoryType", "fhir.resources.STU3.encounter.EncounterStatusHistory"
)

EndpointType = create_fhir_type("EndpointType", "fhir.resources.STU3.endpoint.Endpoint")

EnrollmentRequestType = create_fhir_type(
    "EnrollmentRequestType", "fhir.resources.STU3.enrollmentrequest.EnrollmentRequest"
)

EnrollmentResponseType = create_fhir_type(
    "EnrollmentResponseType",
    "fhir.resources.STU3.enrollmentresponse.EnrollmentResponse",
)

EpisodeOfCareType = create_fhir_type(
    "EpisodeOfCareType", "fhir.resources.STU3.episodeofcare.EpisodeOfCare"
)

EpisodeOfCareDiagnosisType = create_fhir_type(
    "EpisodeOfCareDiagnosisType",
    "fhir.resources.STU3.episodeofcare.EpisodeOfCareDiagnosis",
)

EpisodeOfCareStatusHistoryType = create_fhir_type(
    "EpisodeOfCareStatusHistoryType",
    "fhir.resources.STU3.episodeofcare.EpisodeOfCareStatusHistory",
)

ExpansionProfileType = create_fhir_type(
    "ExpansionProfileType", "fhir.resources.STU3.expansionprofile.ExpansionProfile"
)

ExpansionProfileDesignationType = create_fhir_type(
    "ExpansionProfileDesignationType",
    "fhir.resources.STU3.expansionprofile.ExpansionProfileDesignation",
)

ExpansionProfileDesignationExcludeType = create_fhir_type(
    "ExpansionProfileDesignationExcludeType",
    "fhir.resources.STU3.expansionprofile.ExpansionProfileDesignationExclude",
)

ExpansionProfileDesignationExcludeDesignationType = create_fhir_type(
    "ExpansionProfileDesignationExcludeDesignationType",
    "fhir.resources.STU3.expansionprofile.ExpansionProfileDesignationExcludeDesignation",
)

ExpansionProfileDesignationIncludeType = create_fhir_type(
    "ExpansionProfileDesignationIncludeType",
    "fhir.resources.STU3.expansionprofile.ExpansionProfileDesignationInclude",
)

ExpansionProfileDesignationIncludeDesignationType = create_fhir_type(
    "ExpansionProfileDesignationIncludeDesignationType",
    "fhir.resources.STU3.expansionprofile.ExpansionProfileDesignationIncludeDesignation",
)

ExpansionProfileExcludedSystemType = create_fhir_type(
    "ExpansionProfileExcludedSystemType",
    "fhir.resources.STU3.expansionprofile.ExpansionProfileExcludedSystem",
)

ExpansionProfileFixedVersionType = create_fhir_type(
    "ExpansionProfileFixedVersionType",
    "fhir.resources.STU3.expansionprofile.ExpansionProfileFixedVersion",
)

ExplanationOfBenefitType = create_fhir_type(
    "ExplanationOfBenefitType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefit",
)

ExplanationOfBenefitAccidentType = create_fhir_type(
    "ExplanationOfBenefitAccidentType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitAccident",
)

ExplanationOfBenefitAddItemType = create_fhir_type(
    "ExplanationOfBenefitAddItemType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitAddItem",
)

ExplanationOfBenefitAddItemDetailType = create_fhir_type(
    "ExplanationOfBenefitAddItemDetailType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitAddItemDetail",
)

ExplanationOfBenefitBenefitBalanceType = create_fhir_type(
    "ExplanationOfBenefitBenefitBalanceType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitBenefitBalance",
)

ExplanationOfBenefitBenefitBalanceFinancialType = create_fhir_type(
    "ExplanationOfBenefitBenefitBalanceFinancialType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitBenefitBalanceFinancial",
)

ExplanationOfBenefitCareTeamType = create_fhir_type(
    "ExplanationOfBenefitCareTeamType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitCareTeam",
)

ExplanationOfBenefitDiagnosisType = create_fhir_type(
    "ExplanationOfBenefitDiagnosisType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitDiagnosis",
)

ExplanationOfBenefitInformationType = create_fhir_type(
    "ExplanationOfBenefitInformationType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitInformation",
)

ExplanationOfBenefitInsuranceType = create_fhir_type(
    "ExplanationOfBenefitInsuranceType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitInsurance",
)

ExplanationOfBenefitItemType = create_fhir_type(
    "ExplanationOfBenefitItemType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitItem",
)

ExplanationOfBenefitItemAdjudicationType = create_fhir_type(
    "ExplanationOfBenefitItemAdjudicationType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitItemAdjudication",
)

ExplanationOfBenefitItemDetailType = create_fhir_type(
    "ExplanationOfBenefitItemDetailType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitItemDetail",
)

ExplanationOfBenefitItemDetailSubDetailType = create_fhir_type(
    "ExplanationOfBenefitItemDetailSubDetailType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitItemDetailSubDetail",
)

ExplanationOfBenefitPayeeType = create_fhir_type(
    "ExplanationOfBenefitPayeeType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitPayee",
)

ExplanationOfBenefitPaymentType = create_fhir_type(
    "ExplanationOfBenefitPaymentType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitPayment",
)

ExplanationOfBenefitProcedureType = create_fhir_type(
    "ExplanationOfBenefitProcedureType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitProcedure",
)

ExplanationOfBenefitProcessNoteType = create_fhir_type(
    "ExplanationOfBenefitProcessNoteType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitProcessNote",
)

ExplanationOfBenefitRelatedType = create_fhir_type(
    "ExplanationOfBenefitRelatedType",
    "fhir.resources.STU3.explanationofbenefit.ExplanationOfBenefitRelated",
)

ExtensionType = create_fhir_type(
    "ExtensionType", "fhir.resources.STU3.extension.Extension"
)

FamilyMemberHistoryType = create_fhir_type(
    "FamilyMemberHistoryType",
    "fhir.resources.STU3.familymemberhistory.FamilyMemberHistory",
)

FamilyMemberHistoryConditionType = create_fhir_type(
    "FamilyMemberHistoryConditionType",
    "fhir.resources.STU3.familymemberhistory.FamilyMemberHistoryCondition",
)

FlagType = create_fhir_type("FlagType", "fhir.resources.STU3.flag.Flag")

GoalType = create_fhir_type("GoalType", "fhir.resources.STU3.goal.Goal")

GoalTargetType = create_fhir_type(
    "GoalTargetType", "fhir.resources.STU3.goal.GoalTarget"
)

GraphDefinitionType = create_fhir_type(
    "GraphDefinitionType", "fhir.resources.STU3.graphdefinition.GraphDefinition"
)

GraphDefinitionLinkType = create_fhir_type(
    "GraphDefinitionLinkType", "fhir.resources.STU3.graphdefinition.GraphDefinitionLink"
)

GraphDefinitionLinkTargetType = create_fhir_type(
    "GraphDefinitionLinkTargetType",
    "fhir.resources.STU3.graphdefinition.GraphDefinitionLinkTarget",
)

GraphDefinitionLinkTargetCompartmentType = create_fhir_type(
    "GraphDefinitionLinkTargetCompartmentType",
    "fhir.resources.STU3.graphdefinition.GraphDefinitionLinkTargetCompartment",
)

GroupType = create_fhir_type("GroupType", "fhir.resources.STU3.group.Group")

GroupCharacteristicType = create_fhir_type(
    "GroupCharacteristicType", "fhir.resources.STU3.group.GroupCharacteristic"
)

GroupMemberType = create_fhir_type(
    "GroupMemberType", "fhir.resources.STU3.group.GroupMember"
)

GuidanceResponseType = create_fhir_type(
    "GuidanceResponseType", "fhir.resources.STU3.guidanceresponse.GuidanceResponse"
)

HealthcareServiceType = create_fhir_type(
    "HealthcareServiceType", "fhir.resources.STU3.healthcareservice.HealthcareService"
)

HealthcareServiceAvailableTimeType = create_fhir_type(
    "HealthcareServiceAvailableTimeType",
    "fhir.resources.STU3.healthcareservice.HealthcareServiceAvailableTime",
)

HealthcareServiceNotAvailableType = create_fhir_type(
    "HealthcareServiceNotAvailableType",
    "fhir.resources.STU3.healthcareservice.HealthcareServiceNotAvailable",
)

HumanNameType = create_fhir_type(
    "HumanNameType", "fhir.resources.STU3.humanname.HumanName"
)

IdentifierType = create_fhir_type(
    "IdentifierType", "fhir.resources.STU3.identifier.Identifier"
)

ImagingManifestType = create_fhir_type(
    "ImagingManifestType", "fhir.resources.STU3.imagingmanifest.ImagingManifest"
)

ImagingManifestStudyType = create_fhir_type(
    "ImagingManifestStudyType",
    "fhir.resources.STU3.imagingmanifest.ImagingManifestStudy",
)

ImagingManifestStudySeriesType = create_fhir_type(
    "ImagingManifestStudySeriesType",
    "fhir.resources.STU3.imagingmanifest.ImagingManifestStudySeries",
)

ImagingManifestStudySeriesInstanceType = create_fhir_type(
    "ImagingManifestStudySeriesInstanceType",
    "fhir.resources.STU3.imagingmanifest.ImagingManifestStudySeriesInstance",
)

ImagingStudyType = create_fhir_type(
    "ImagingStudyType", "fhir.resources.STU3.imagingstudy.ImagingStudy"
)

ImagingStudySeriesType = create_fhir_type(
    "ImagingStudySeriesType", "fhir.resources.STU3.imagingstudy.ImagingStudySeries"
)

ImagingStudySeriesInstanceType = create_fhir_type(
    "ImagingStudySeriesInstanceType",
    "fhir.resources.STU3.imagingstudy.ImagingStudySeriesInstance",
)

ImmunizationType = create_fhir_type(
    "ImmunizationType", "fhir.resources.STU3.immunization.Immunization"
)

ImmunizationExplanationType = create_fhir_type(
    "ImmunizationExplanationType",
    "fhir.resources.STU3.immunization.ImmunizationExplanation",
)

ImmunizationPractitionerType = create_fhir_type(
    "ImmunizationPractitionerType",
    "fhir.resources.STU3.immunization.ImmunizationPractitioner",
)

ImmunizationReactionType = create_fhir_type(
    "ImmunizationReactionType", "fhir.resources.STU3.immunization.ImmunizationReaction"
)

ImmunizationRecommendationType = create_fhir_type(
    "ImmunizationRecommendationType",
    "fhir.resources.STU3.immunizationrecommendation.ImmunizationRecommendation",
)

ImmunizationRecommendationRecommendationType = create_fhir_type(
    "ImmunizationRecommendationRecommendationType",
    "fhir.resources.STU3.immunizationrecommendation.ImmunizationRecommendationRecommendation",
)

ImmunizationRecommendationRecommendationDateCriterionType = create_fhir_type(
    "ImmunizationRecommendationRecommendationDateCriterionType",
    "fhir.resources.STU3.immunizationrecommendation.ImmunizationRecommendationRecommendationDateCriterion",
)

ImmunizationRecommendationRecommendationProtocolType = create_fhir_type(
    "ImmunizationRecommendationRecommendationProtocolType",
    "fhir.resources.STU3.immunizationrecommendation.ImmunizationRecommendationRecommendationProtocol",
)

ImmunizationVaccinationProtocolType = create_fhir_type(
    "ImmunizationVaccinationProtocolType",
    "fhir.resources.STU3.immunization.ImmunizationVaccinationProtocol",
)

ImplementationGuideType = create_fhir_type(
    "ImplementationGuideType",
    "fhir.resources.STU3.implementationguide.ImplementationGuide",
)

ImplementationGuideDependencyType = create_fhir_type(
    "ImplementationGuideDependencyType",
    "fhir.resources.STU3.implementationguide.ImplementationGuideDependency",
)

ImplementationGuideGlobalType = create_fhir_type(
    "ImplementationGuideGlobalType",
    "fhir.resources.STU3.implementationguide.ImplementationGuideGlobal",
)

ImplementationGuidePackageType = create_fhir_type(
    "ImplementationGuidePackageType",
    "fhir.resources.STU3.implementationguide.ImplementationGuidePackage",
)

ImplementationGuidePackageResourceType = create_fhir_type(
    "ImplementationGuidePackageResourceType",
    "fhir.resources.STU3.implementationguide.ImplementationGuidePackageResource",
)

ImplementationGuidePageType = create_fhir_type(
    "ImplementationGuidePageType",
    "fhir.resources.STU3.implementationguide.ImplementationGuidePage",
)

LibraryType = create_fhir_type("LibraryType", "fhir.resources.STU3.library.Library")

LinkageType = create_fhir_type("LinkageType", "fhir.resources.STU3.linkage.Linkage")

LinkageItemType = create_fhir_type(
    "LinkageItemType", "fhir.resources.STU3.linkage.LinkageItem"
)

ListType = create_fhir_type("ListType", "fhir.resources.STU3.list.List")

ListEntryType = create_fhir_type("ListEntryType", "fhir.resources.STU3.list.ListEntry")

LocationType = create_fhir_type("LocationType", "fhir.resources.STU3.location.Location")

LocationPositionType = create_fhir_type(
    "LocationPositionType", "fhir.resources.STU3.location.LocationPosition"
)

MeasureType = create_fhir_type("MeasureType", "fhir.resources.STU3.measure.Measure")

MeasureGroupType = create_fhir_type(
    "MeasureGroupType", "fhir.resources.STU3.measure.MeasureGroup"
)

MeasureGroupPopulationType = create_fhir_type(
    "MeasureGroupPopulationType", "fhir.resources.STU3.measure.MeasureGroupPopulation"
)

MeasureGroupStratifierType = create_fhir_type(
    "MeasureGroupStratifierType", "fhir.resources.STU3.measure.MeasureGroupStratifier"
)

MeasureReportType = create_fhir_type(
    "MeasureReportType", "fhir.resources.STU3.measurereport.MeasureReport"
)

MeasureReportGroupType = create_fhir_type(
    "MeasureReportGroupType", "fhir.resources.STU3.measurereport.MeasureReportGroup"
)

MeasureReportGroupPopulationType = create_fhir_type(
    "MeasureReportGroupPopulationType",
    "fhir.resources.STU3.measurereport.MeasureReportGroupPopulation",
)

MeasureReportGroupStratifierType = create_fhir_type(
    "MeasureReportGroupStratifierType",
    "fhir.resources.STU3.measurereport.MeasureReportGroupStratifier",
)

MeasureReportGroupStratifierStratumType = create_fhir_type(
    "MeasureReportGroupStratifierStratumType",
    "fhir.resources.STU3.measurereport.MeasureReportGroupStratifierStratum",
)

MeasureReportGroupStratifierStratumPopulationType = create_fhir_type(
    "MeasureReportGroupStratifierStratumPopulationType",
    "fhir.resources.STU3.measurereport.MeasureReportGroupStratifierStratumPopulation",
)

MeasureSupplementalDataType = create_fhir_type(
    "MeasureSupplementalDataType", "fhir.resources.STU3.measure.MeasureSupplementalData"
)

MediaType = create_fhir_type("MediaType", "fhir.resources.STU3.media.Media")

MedicationType = create_fhir_type(
    "MedicationType", "fhir.resources.STU3.medication.Medication"
)

MedicationAdministrationType = create_fhir_type(
    "MedicationAdministrationType",
    "fhir.resources.STU3.medicationadministration.MedicationAdministration",
)

MedicationAdministrationDosageType = create_fhir_type(
    "MedicationAdministrationDosageType",
    "fhir.resources.STU3.medicationadministration.MedicationAdministrationDosage",
)

MedicationAdministrationPerformerType = create_fhir_type(
    "MedicationAdministrationPerformerType",
    "fhir.resources.STU3.medicationadministration.MedicationAdministrationPerformer",
)

MedicationDispenseType = create_fhir_type(
    "MedicationDispenseType",
    "fhir.resources.STU3.medicationdispense.MedicationDispense",
)

MedicationDispensePerformerType = create_fhir_type(
    "MedicationDispensePerformerType",
    "fhir.resources.STU3.medicationdispense.MedicationDispensePerformer",
)

MedicationDispenseSubstitutionType = create_fhir_type(
    "MedicationDispenseSubstitutionType",
    "fhir.resources.STU3.medicationdispense.MedicationDispenseSubstitution",
)

MedicationIngredientType = create_fhir_type(
    "MedicationIngredientType", "fhir.resources.STU3.medication.MedicationIngredient"
)

MedicationPackageType = create_fhir_type(
    "MedicationPackageType", "fhir.resources.STU3.medication.MedicationPackage"
)

MedicationPackageBatchType = create_fhir_type(
    "MedicationPackageBatchType",
    "fhir.resources.STU3.medication.MedicationPackageBatch",
)

MedicationPackageContentType = create_fhir_type(
    "MedicationPackageContentType",
    "fhir.resources.STU3.medication.MedicationPackageContent",
)

MedicationRequestType = create_fhir_type(
    "MedicationRequestType", "fhir.resources.STU3.medicationrequest.MedicationRequest"
)

MedicationRequestDispenseRequestType = create_fhir_type(
    "MedicationRequestDispenseRequestType",
    "fhir.resources.STU3.medicationrequest.MedicationRequestDispenseRequest",
)

MedicationRequestRequesterType = create_fhir_type(
    "MedicationRequestRequesterType",
    "fhir.resources.STU3.medicationrequest.MedicationRequestRequester",
)

MedicationRequestSubstitutionType = create_fhir_type(
    "MedicationRequestSubstitutionType",
    "fhir.resources.STU3.medicationrequest.MedicationRequestSubstitution",
)

MedicationStatementType = create_fhir_type(
    "MedicationStatementType",
    "fhir.resources.STU3.medicationstatement.MedicationStatement",
)

MessageDefinitionType = create_fhir_type(
    "MessageDefinitionType", "fhir.resources.STU3.messagedefinition.MessageDefinition"
)

MessageDefinitionAllowedResponseType = create_fhir_type(
    "MessageDefinitionAllowedResponseType",
    "fhir.resources.STU3.messagedefinition.MessageDefinitionAllowedResponse",
)

MessageDefinitionFocusType = create_fhir_type(
    "MessageDefinitionFocusType",
    "fhir.resources.STU3.messagedefinition.MessageDefinitionFocus",
)

MessageHeaderType = create_fhir_type(
    "MessageHeaderType", "fhir.resources.STU3.messageheader.MessageHeader"
)

MessageHeaderDestinationType = create_fhir_type(
    "MessageHeaderDestinationType",
    "fhir.resources.STU3.messageheader.MessageHeaderDestination",
)

MessageHeaderResponseType = create_fhir_type(
    "MessageHeaderResponseType",
    "fhir.resources.STU3.messageheader.MessageHeaderResponse",
)

MessageHeaderSourceType = create_fhir_type(
    "MessageHeaderSourceType", "fhir.resources.STU3.messageheader.MessageHeaderSource"
)

MetaType = create_fhir_type("MetaType", "fhir.resources.STU3.meta.Meta")

MetadataResourceType = create_fhir_type(
    "MetadataResourceType", "fhir.resources.STU3.metadataresource.MetadataResource"
)

MoneyType = create_fhir_type("MoneyType", "fhir.resources.STU3.money.Money")

NamingSystemType = create_fhir_type(
    "NamingSystemType", "fhir.resources.STU3.namingsystem.NamingSystem"
)

NamingSystemUniqueIdType = create_fhir_type(
    "NamingSystemUniqueIdType", "fhir.resources.STU3.namingsystem.NamingSystemUniqueId"
)

NarrativeType = create_fhir_type(
    "NarrativeType", "fhir.resources.STU3.narrative.Narrative"
)

NutritionOrderType = create_fhir_type(
    "NutritionOrderType", "fhir.resources.STU3.nutritionorder.NutritionOrder"
)

NutritionOrderEnteralFormulaType = create_fhir_type(
    "NutritionOrderEnteralFormulaType",
    "fhir.resources.STU3.nutritionorder.NutritionOrderEnteralFormula",
)

NutritionOrderEnteralFormulaAdministrationType = create_fhir_type(
    "NutritionOrderEnteralFormulaAdministrationType",
    "fhir.resources.STU3.nutritionorder.NutritionOrderEnteralFormulaAdministration",
)

NutritionOrderOralDietType = create_fhir_type(
    "NutritionOrderOralDietType",
    "fhir.resources.STU3.nutritionorder.NutritionOrderOralDiet",
)

NutritionOrderOralDietNutrientType = create_fhir_type(
    "NutritionOrderOralDietNutrientType",
    "fhir.resources.STU3.nutritionorder.NutritionOrderOralDietNutrient",
)

NutritionOrderOralDietTextureType = create_fhir_type(
    "NutritionOrderOralDietTextureType",
    "fhir.resources.STU3.nutritionorder.NutritionOrderOralDietTexture",
)

NutritionOrderSupplementType = create_fhir_type(
    "NutritionOrderSupplementType",
    "fhir.resources.STU3.nutritionorder.NutritionOrderSupplement",
)

ObservationType = create_fhir_type(
    "ObservationType", "fhir.resources.STU3.observation.Observation"
)

ObservationComponentType = create_fhir_type(
    "ObservationComponentType", "fhir.resources.STU3.observation.ObservationComponent"
)

ObservationReferenceRangeType = create_fhir_type(
    "ObservationReferenceRangeType",
    "fhir.resources.STU3.observation.ObservationReferenceRange",
)

ObservationRelatedType = create_fhir_type(
    "ObservationRelatedType", "fhir.resources.STU3.observation.ObservationRelated"
)

OperationDefinitionType = create_fhir_type(
    "OperationDefinitionType",
    "fhir.resources.STU3.operationdefinition.OperationDefinition",
)

OperationDefinitionOverloadType = create_fhir_type(
    "OperationDefinitionOverloadType",
    "fhir.resources.STU3.operationdefinition.OperationDefinitionOverload",
)

OperationDefinitionParameterType = create_fhir_type(
    "OperationDefinitionParameterType",
    "fhir.resources.STU3.operationdefinition.OperationDefinitionParameter",
)

OperationDefinitionParameterBindingType = create_fhir_type(
    "OperationDefinitionParameterBindingType",
    "fhir.resources.STU3.operationdefinition.OperationDefinitionParameterBinding",
)

OperationOutcomeType = create_fhir_type(
    "OperationOutcomeType", "fhir.resources.STU3.operationoutcome.OperationOutcome"
)

OperationOutcomeIssueType = create_fhir_type(
    "OperationOutcomeIssueType",
    "fhir.resources.STU3.operationoutcome.OperationOutcomeIssue",
)

OrganizationType = create_fhir_type(
    "OrganizationType", "fhir.resources.STU3.organization.Organization"
)

OrganizationContactType = create_fhir_type(
    "OrganizationContactType", "fhir.resources.STU3.organization.OrganizationContact"
)

ParameterDefinitionType = create_fhir_type(
    "ParameterDefinitionType",
    "fhir.resources.STU3.parameterdefinition.ParameterDefinition",
)

ParametersType = create_fhir_type(
    "ParametersType", "fhir.resources.STU3.parameters.Parameters"
)

ParametersParameterType = create_fhir_type(
    "ParametersParameterType", "fhir.resources.STU3.parameters.ParametersParameter"
)

PatientType = create_fhir_type("PatientType", "fhir.resources.STU3.patient.Patient")

PatientAnimalType = create_fhir_type(
    "PatientAnimalType", "fhir.resources.STU3.patient.PatientAnimal"
)

PatientCommunicationType = create_fhir_type(
    "PatientCommunicationType", "fhir.resources.STU3.patient.PatientCommunication"
)

PatientContactType = create_fhir_type(
    "PatientContactType", "fhir.resources.STU3.patient.PatientContact"
)

PatientLinkType = create_fhir_type(
    "PatientLinkType", "fhir.resources.STU3.patient.PatientLink"
)

PaymentNoticeType = create_fhir_type(
    "PaymentNoticeType", "fhir.resources.STU3.paymentnotice.PaymentNotice"
)

PaymentReconciliationType = create_fhir_type(
    "PaymentReconciliationType",
    "fhir.resources.STU3.paymentreconciliation.PaymentReconciliation",
)

PaymentReconciliationDetailType = create_fhir_type(
    "PaymentReconciliationDetailType",
    "fhir.resources.STU3.paymentreconciliation.PaymentReconciliationDetail",
)

PaymentReconciliationProcessNoteType = create_fhir_type(
    "PaymentReconciliationProcessNoteType",
    "fhir.resources.STU3.paymentreconciliation.PaymentReconciliationProcessNote",
)

PeriodType = create_fhir_type("PeriodType", "fhir.resources.STU3.period.Period")

PersonType = create_fhir_type("PersonType", "fhir.resources.STU3.person.Person")

PersonLinkType = create_fhir_type(
    "PersonLinkType", "fhir.resources.STU3.person.PersonLink"
)

PlanDefinitionType = create_fhir_type(
    "PlanDefinitionType", "fhir.resources.STU3.plandefinition.PlanDefinition"
)

PlanDefinitionActionType = create_fhir_type(
    "PlanDefinitionActionType",
    "fhir.resources.STU3.plandefinition.PlanDefinitionAction",
)

PlanDefinitionActionConditionType = create_fhir_type(
    "PlanDefinitionActionConditionType",
    "fhir.resources.STU3.plandefinition.PlanDefinitionActionCondition",
)

PlanDefinitionActionDynamicValueType = create_fhir_type(
    "PlanDefinitionActionDynamicValueType",
    "fhir.resources.STU3.plandefinition.PlanDefinitionActionDynamicValue",
)

PlanDefinitionActionParticipantType = create_fhir_type(
    "PlanDefinitionActionParticipantType",
    "fhir.resources.STU3.plandefinition.PlanDefinitionActionParticipant",
)

PlanDefinitionActionRelatedActionType = create_fhir_type(
    "PlanDefinitionActionRelatedActionType",
    "fhir.resources.STU3.plandefinition.PlanDefinitionActionRelatedAction",
)

PlanDefinitionGoalType = create_fhir_type(
    "PlanDefinitionGoalType", "fhir.resources.STU3.plandefinition.PlanDefinitionGoal"
)

PlanDefinitionGoalTargetType = create_fhir_type(
    "PlanDefinitionGoalTargetType",
    "fhir.resources.STU3.plandefinition.PlanDefinitionGoalTarget",
)

PractitionerType = create_fhir_type(
    "PractitionerType", "fhir.resources.STU3.practitioner.Practitioner"
)

PractitionerQualificationType = create_fhir_type(
    "PractitionerQualificationType",
    "fhir.resources.STU3.practitioner.PractitionerQualification",
)

PractitionerRoleType = create_fhir_type(
    "PractitionerRoleType", "fhir.resources.STU3.practitionerrole.PractitionerRole"
)

PractitionerRoleAvailableTimeType = create_fhir_type(
    "PractitionerRoleAvailableTimeType",
    "fhir.resources.STU3.practitionerrole.PractitionerRoleAvailableTime",
)

PractitionerRoleNotAvailableType = create_fhir_type(
    "PractitionerRoleNotAvailableType",
    "fhir.resources.STU3.practitionerrole.PractitionerRoleNotAvailable",
)

ProcedureType = create_fhir_type(
    "ProcedureType", "fhir.resources.STU3.procedure.Procedure"
)

ProcedureFocalDeviceType = create_fhir_type(
    "ProcedureFocalDeviceType", "fhir.resources.STU3.procedure.ProcedureFocalDevice"
)

ProcedurePerformerType = create_fhir_type(
    "ProcedurePerformerType", "fhir.resources.STU3.procedure.ProcedurePerformer"
)

ProcedureRequestType = create_fhir_type(
    "ProcedureRequestType", "fhir.resources.STU3.procedurerequest.ProcedureRequest"
)

ProcedureRequestRequesterType = create_fhir_type(
    "ProcedureRequestRequesterType",
    "fhir.resources.STU3.procedurerequest.ProcedureRequestRequester",
)

ProcessRequestType = create_fhir_type(
    "ProcessRequestType", "fhir.resources.STU3.processrequest.ProcessRequest"
)

ProcessRequestItemType = create_fhir_type(
    "ProcessRequestItemType", "fhir.resources.STU3.processrequest.ProcessRequestItem"
)

ProcessResponseType = create_fhir_type(
    "ProcessResponseType", "fhir.resources.STU3.processresponse.ProcessResponse"
)

ProcessResponseProcessNoteType = create_fhir_type(
    "ProcessResponseProcessNoteType",
    "fhir.resources.STU3.processresponse.ProcessResponseProcessNote",
)

ProvenanceType = create_fhir_type(
    "ProvenanceType", "fhir.resources.STU3.provenance.Provenance"
)

ProvenanceAgentType = create_fhir_type(
    "ProvenanceAgentType", "fhir.resources.STU3.provenance.ProvenanceAgent"
)

ProvenanceEntityType = create_fhir_type(
    "ProvenanceEntityType", "fhir.resources.STU3.provenance.ProvenanceEntity"
)

QuantityType = create_fhir_type("QuantityType", "fhir.resources.STU3.quantity.Quantity")

QuestionnaireType = create_fhir_type(
    "QuestionnaireType", "fhir.resources.STU3.questionnaire.Questionnaire"
)

QuestionnaireItemType = create_fhir_type(
    "QuestionnaireItemType", "fhir.resources.STU3.questionnaire.QuestionnaireItem"
)

QuestionnaireItemEnableWhenType = create_fhir_type(
    "QuestionnaireItemEnableWhenType",
    "fhir.resources.STU3.questionnaire.QuestionnaireItemEnableWhen",
)

QuestionnaireItemOptionType = create_fhir_type(
    "QuestionnaireItemOptionType",
    "fhir.resources.STU3.questionnaire.QuestionnaireItemOption",
)

QuestionnaireResponseType = create_fhir_type(
    "QuestionnaireResponseType",
    "fhir.resources.STU3.questionnaireresponse.QuestionnaireResponse",
)

QuestionnaireResponseItemType = create_fhir_type(
    "QuestionnaireResponseItemType",
    "fhir.resources.STU3.questionnaireresponse.QuestionnaireResponseItem",
)

QuestionnaireResponseItemAnswerType = create_fhir_type(
    "QuestionnaireResponseItemAnswerType",
    "fhir.resources.STU3.questionnaireresponse.QuestionnaireResponseItemAnswer",
)

RangeType = create_fhir_type("RangeType", "fhir.resources.STU3.range.Range")

RatioType = create_fhir_type("RatioType", "fhir.resources.STU3.ratio.Ratio")

ReferenceType = create_fhir_type(
    "ReferenceType", "fhir.resources.STU3.reference.Reference"
)

ReferralRequestType = create_fhir_type(
    "ReferralRequestType", "fhir.resources.STU3.referralrequest.ReferralRequest"
)

ReferralRequestRequesterType = create_fhir_type(
    "ReferralRequestRequesterType",
    "fhir.resources.STU3.referralrequest.ReferralRequestRequester",
)

RelatedArtifactType = create_fhir_type(
    "RelatedArtifactType", "fhir.resources.STU3.relatedartifact.RelatedArtifact"
)

RelatedPersonType = create_fhir_type(
    "RelatedPersonType", "fhir.resources.STU3.relatedperson.RelatedPerson"
)

RequestGroupType = create_fhir_type(
    "RequestGroupType", "fhir.resources.STU3.requestgroup.RequestGroup"
)

RequestGroupActionType = create_fhir_type(
    "RequestGroupActionType", "fhir.resources.STU3.requestgroup.RequestGroupAction"
)

RequestGroupActionConditionType = create_fhir_type(
    "RequestGroupActionConditionType",
    "fhir.resources.STU3.requestgroup.RequestGroupActionCondition",
)

RequestGroupActionRelatedActionType = create_fhir_type(
    "RequestGroupActionRelatedActionType",
    "fhir.resources.STU3.requestgroup.RequestGroupActionRelatedAction",
)

ResearchStudyType = create_fhir_type(
    "ResearchStudyType", "fhir.resources.STU3.researchstudy.ResearchStudy"
)

ResearchStudyArmType = create_fhir_type(
    "ResearchStudyArmType", "fhir.resources.STU3.researchstudy.ResearchStudyArm"
)

ResearchSubjectType = create_fhir_type(
    "ResearchSubjectType", "fhir.resources.STU3.researchsubject.ResearchSubject"
)

RiskAssessmentType = create_fhir_type(
    "RiskAssessmentType", "fhir.resources.STU3.riskassessment.RiskAssessment"
)

RiskAssessmentPredictionType = create_fhir_type(
    "RiskAssessmentPredictionType",
    "fhir.resources.STU3.riskassessment.RiskAssessmentPrediction",
)

SampledDataType = create_fhir_type(
    "SampledDataType", "fhir.resources.STU3.sampleddata.SampledData"
)

ScheduleType = create_fhir_type("ScheduleType", "fhir.resources.STU3.schedule.Schedule")

SearchParameterType = create_fhir_type(
    "SearchParameterType", "fhir.resources.STU3.searchparameter.SearchParameter"
)

SearchParameterComponentType = create_fhir_type(
    "SearchParameterComponentType",
    "fhir.resources.STU3.searchparameter.SearchParameterComponent",
)

SequenceType = create_fhir_type("SequenceType", "fhir.resources.STU3.sequence.Sequence")

SequenceQualityType = create_fhir_type(
    "SequenceQualityType", "fhir.resources.STU3.sequence.SequenceQuality"
)

SequenceReferenceSeqType = create_fhir_type(
    "SequenceReferenceSeqType", "fhir.resources.STU3.sequence.SequenceReferenceSeq"
)

SequenceRepositoryType = create_fhir_type(
    "SequenceRepositoryType", "fhir.resources.STU3.sequence.SequenceRepository"
)

SequenceVariantType = create_fhir_type(
    "SequenceVariantType", "fhir.resources.STU3.sequence.SequenceVariant"
)

ServiceDefinitionType = create_fhir_type(
    "ServiceDefinitionType", "fhir.resources.STU3.servicedefinition.ServiceDefinition"
)

SignatureType = create_fhir_type(
    "SignatureType", "fhir.resources.STU3.signature.Signature"
)

SlotType = create_fhir_type("SlotType", "fhir.resources.STU3.slot.Slot")

SpecimenType = create_fhir_type("SpecimenType", "fhir.resources.STU3.specimen.Specimen")

SpecimenCollectionType = create_fhir_type(
    "SpecimenCollectionType", "fhir.resources.STU3.specimen.SpecimenCollection"
)

SpecimenContainerType = create_fhir_type(
    "SpecimenContainerType", "fhir.resources.STU3.specimen.SpecimenContainer"
)

SpecimenProcessingType = create_fhir_type(
    "SpecimenProcessingType", "fhir.resources.STU3.specimen.SpecimenProcessing"
)

StructureDefinitionType = create_fhir_type(
    "StructureDefinitionType",
    "fhir.resources.STU3.structuredefinition.StructureDefinition",
)

StructureDefinitionDifferentialType = create_fhir_type(
    "StructureDefinitionDifferentialType",
    "fhir.resources.STU3.structuredefinition.StructureDefinitionDifferential",
)

StructureDefinitionMappingType = create_fhir_type(
    "StructureDefinitionMappingType",
    "fhir.resources.STU3.structuredefinition.StructureDefinitionMapping",
)

StructureDefinitionSnapshotType = create_fhir_type(
    "StructureDefinitionSnapshotType",
    "fhir.resources.STU3.structuredefinition.StructureDefinitionSnapshot",
)

StructureMapType = create_fhir_type(
    "StructureMapType", "fhir.resources.STU3.structuremap.StructureMap"
)

StructureMapGroupType = create_fhir_type(
    "StructureMapGroupType", "fhir.resources.STU3.structuremap.StructureMapGroup"
)

StructureMapGroupInputType = create_fhir_type(
    "StructureMapGroupInputType",
    "fhir.resources.STU3.structuremap.StructureMapGroupInput",
)

StructureMapGroupRuleType = create_fhir_type(
    "StructureMapGroupRuleType",
    "fhir.resources.STU3.structuremap.StructureMapGroupRule",
)

StructureMapGroupRuleDependentType = create_fhir_type(
    "StructureMapGroupRuleDependentType",
    "fhir.resources.STU3.structuremap.StructureMapGroupRuleDependent",
)

StructureMapGroupRuleSourceType = create_fhir_type(
    "StructureMapGroupRuleSourceType",
    "fhir.resources.STU3.structuremap.StructureMapGroupRuleSource",
)

StructureMapGroupRuleTargetType = create_fhir_type(
    "StructureMapGroupRuleTargetType",
    "fhir.resources.STU3.structuremap.StructureMapGroupRuleTarget",
)

StructureMapGroupRuleTargetParameterType = create_fhir_type(
    "StructureMapGroupRuleTargetParameterType",
    "fhir.resources.STU3.structuremap.StructureMapGroupRuleTargetParameter",
)

StructureMapStructureType = create_fhir_type(
    "StructureMapStructureType",
    "fhir.resources.STU3.structuremap.StructureMapStructure",
)

SubscriptionType = create_fhir_type(
    "SubscriptionType", "fhir.resources.STU3.subscription.Subscription"
)

SubscriptionChannelType = create_fhir_type(
    "SubscriptionChannelType", "fhir.resources.STU3.subscription.SubscriptionChannel"
)

SubstanceType = create_fhir_type(
    "SubstanceType", "fhir.resources.STU3.substance.Substance"
)

SubstanceIngredientType = create_fhir_type(
    "SubstanceIngredientType", "fhir.resources.STU3.substance.SubstanceIngredient"
)

SubstanceInstanceType = create_fhir_type(
    "SubstanceInstanceType", "fhir.resources.STU3.substance.SubstanceInstance"
)

SupplyDeliveryType = create_fhir_type(
    "SupplyDeliveryType", "fhir.resources.STU3.supplydelivery.SupplyDelivery"
)

SupplyDeliverySuppliedItemType = create_fhir_type(
    "SupplyDeliverySuppliedItemType",
    "fhir.resources.STU3.supplydelivery.SupplyDeliverySuppliedItem",
)

SupplyRequestType = create_fhir_type(
    "SupplyRequestType", "fhir.resources.STU3.supplyrequest.SupplyRequest"
)

SupplyRequestOrderedItemType = create_fhir_type(
    "SupplyRequestOrderedItemType",
    "fhir.resources.STU3.supplyrequest.SupplyRequestOrderedItem",
)

SupplyRequestRequesterType = create_fhir_type(
    "SupplyRequestRequesterType",
    "fhir.resources.STU3.supplyrequest.SupplyRequestRequester",
)

TaskType = create_fhir_type("TaskType", "fhir.resources.STU3.task.Task")

TaskInputType = create_fhir_type("TaskInputType", "fhir.resources.STU3.task.TaskInput")

TaskOutputType = create_fhir_type(
    "TaskOutputType", "fhir.resources.STU3.task.TaskOutput"
)

TaskRequesterType = create_fhir_type(
    "TaskRequesterType", "fhir.resources.STU3.task.TaskRequester"
)

TaskRestrictionType = create_fhir_type(
    "TaskRestrictionType", "fhir.resources.STU3.task.TaskRestriction"
)

TestReportType = create_fhir_type(
    "TestReportType", "fhir.resources.STU3.testreport.TestReport"
)

TestReportParticipantType = create_fhir_type(
    "TestReportParticipantType", "fhir.resources.STU3.testreport.TestReportParticipant"
)

TestReportSetupType = create_fhir_type(
    "TestReportSetupType", "fhir.resources.STU3.testreport.TestReportSetup"
)

TestReportSetupActionType = create_fhir_type(
    "TestReportSetupActionType", "fhir.resources.STU3.testreport.TestReportSetupAction"
)

TestReportSetupActionAssertType = create_fhir_type(
    "TestReportSetupActionAssertType",
    "fhir.resources.STU3.testreport.TestReportSetupActionAssert",
)

TestReportSetupActionOperationType = create_fhir_type(
    "TestReportSetupActionOperationType",
    "fhir.resources.STU3.testreport.TestReportSetupActionOperation",
)

TestReportTeardownType = create_fhir_type(
    "TestReportTeardownType", "fhir.resources.STU3.testreport.TestReportTeardown"
)

TestReportTeardownActionType = create_fhir_type(
    "TestReportTeardownActionType",
    "fhir.resources.STU3.testreport.TestReportTeardownAction",
)

TestReportTestType = create_fhir_type(
    "TestReportTestType", "fhir.resources.STU3.testreport.TestReportTest"
)

TestReportTestActionType = create_fhir_type(
    "TestReportTestActionType", "fhir.resources.STU3.testreport.TestReportTestAction"
)

TestScriptType = create_fhir_type(
    "TestScriptType", "fhir.resources.STU3.testscript.TestScript"
)

TestScriptDestinationType = create_fhir_type(
    "TestScriptDestinationType", "fhir.resources.STU3.testscript.TestScriptDestination"
)

TestScriptFixtureType = create_fhir_type(
    "TestScriptFixtureType", "fhir.resources.STU3.testscript.TestScriptFixture"
)

TestScriptMetadataType = create_fhir_type(
    "TestScriptMetadataType", "fhir.resources.STU3.testscript.TestScriptMetadata"
)

TestScriptMetadataCapabilityType = create_fhir_type(
    "TestScriptMetadataCapabilityType",
    "fhir.resources.STU3.testscript.TestScriptMetadataCapability",
)

TestScriptMetadataLinkType = create_fhir_type(
    "TestScriptMetadataLinkType",
    "fhir.resources.STU3.testscript.TestScriptMetadataLink",
)

TestScriptOriginType = create_fhir_type(
    "TestScriptOriginType", "fhir.resources.STU3.testscript.TestScriptOrigin"
)

TestScriptRuleType = create_fhir_type(
    "TestScriptRuleType", "fhir.resources.STU3.testscript.TestScriptRule"
)

TestScriptRuleParamType = create_fhir_type(
    "TestScriptRuleParamType", "fhir.resources.STU3.testscript.TestScriptRuleParam"
)

TestScriptRulesetType = create_fhir_type(
    "TestScriptRulesetType", "fhir.resources.STU3.testscript.TestScriptRuleset"
)

TestScriptRulesetRuleType = create_fhir_type(
    "TestScriptRulesetRuleType", "fhir.resources.STU3.testscript.TestScriptRulesetRule"
)

TestScriptRulesetRuleParamType = create_fhir_type(
    "TestScriptRulesetRuleParamType",
    "fhir.resources.STU3.testscript.TestScriptRulesetRuleParam",
)

TestScriptSetupType = create_fhir_type(
    "TestScriptSetupType", "fhir.resources.STU3.testscript.TestScriptSetup"
)

TestScriptSetupActionType = create_fhir_type(
    "TestScriptSetupActionType", "fhir.resources.STU3.testscript.TestScriptSetupAction"
)

TestScriptSetupActionAssertType = create_fhir_type(
    "TestScriptSetupActionAssertType",
    "fhir.resources.STU3.testscript.TestScriptSetupActionAssert",
)

TestScriptSetupActionAssertRuleType = create_fhir_type(
    "TestScriptSetupActionAssertRuleType",
    "fhir.resources.STU3.testscript.TestScriptSetupActionAssertRule",
)

TestScriptSetupActionAssertRuleParamType = create_fhir_type(
    "TestScriptSetupActionAssertRuleParamType",
    "fhir.resources.STU3.testscript.TestScriptSetupActionAssertRuleParam",
)

TestScriptSetupActionAssertRulesetType = create_fhir_type(
    "TestScriptSetupActionAssertRulesetType",
    "fhir.resources.STU3.testscript.TestScriptSetupActionAssertRuleset",
)

TestScriptSetupActionAssertRulesetRuleType = create_fhir_type(
    "TestScriptSetupActionAssertRulesetRuleType",
    "fhir.resources.STU3.testscript.TestScriptSetupActionAssertRulesetRule",
)

TestScriptSetupActionAssertRulesetRuleParamType = create_fhir_type(
    "TestScriptSetupActionAssertRulesetRuleParamType",
    "fhir.resources.STU3.testscript.TestScriptSetupActionAssertRulesetRuleParam",
)

TestScriptSetupActionOperationType = create_fhir_type(
    "TestScriptSetupActionOperationType",
    "fhir.resources.STU3.testscript.TestScriptSetupActionOperation",
)

TestScriptSetupActionOperationRequestHeaderType = create_fhir_type(
    "TestScriptSetupActionOperationRequestHeaderType",
    "fhir.resources.STU3.testscript.TestScriptSetupActionOperationRequestHeader",
)

TestScriptTeardownType = create_fhir_type(
    "TestScriptTeardownType", "fhir.resources.STU3.testscript.TestScriptTeardown"
)

TestScriptTeardownActionType = create_fhir_type(
    "TestScriptTeardownActionType",
    "fhir.resources.STU3.testscript.TestScriptTeardownAction",
)

TestScriptTestType = create_fhir_type(
    "TestScriptTestType", "fhir.resources.STU3.testscript.TestScriptTest"
)

TestScriptTestActionType = create_fhir_type(
    "TestScriptTestActionType", "fhir.resources.STU3.testscript.TestScriptTestAction"
)

TestScriptVariableType = create_fhir_type(
    "TestScriptVariableType", "fhir.resources.STU3.testscript.TestScriptVariable"
)

TimingType = create_fhir_type("TimingType", "fhir.resources.STU3.timing.Timing")

TimingRepeatType = create_fhir_type(
    "TimingRepeatType", "fhir.resources.STU3.timing.TimingRepeat"
)

TriggerDefinitionType = create_fhir_type(
    "TriggerDefinitionType", "fhir.resources.STU3.triggerdefinition.TriggerDefinition"
)

UsageContextType = create_fhir_type(
    "UsageContextType", "fhir.resources.STU3.usagecontext.UsageContext"
)

ValueSetType = create_fhir_type("ValueSetType", "fhir.resources.STU3.valueset.ValueSet")

ValueSetComposeType = create_fhir_type(
    "ValueSetComposeType", "fhir.resources.STU3.valueset.ValueSetCompose"
)

ValueSetComposeIncludeType = create_fhir_type(
    "ValueSetComposeIncludeType", "fhir.resources.STU3.valueset.ValueSetComposeInclude"
)

ValueSetComposeIncludeConceptType = create_fhir_type(
    "ValueSetComposeIncludeConceptType",
    "fhir.resources.STU3.valueset.ValueSetComposeIncludeConcept",
)

ValueSetComposeIncludeConceptDesignationType = create_fhir_type(
    "ValueSetComposeIncludeConceptDesignationType",
    "fhir.resources.STU3.valueset.ValueSetComposeIncludeConceptDesignation",
)

ValueSetComposeIncludeFilterType = create_fhir_type(
    "ValueSetComposeIncludeFilterType",
    "fhir.resources.STU3.valueset.ValueSetComposeIncludeFilter",
)

ValueSetExpansionType = create_fhir_type(
    "ValueSetExpansionType", "fhir.resources.STU3.valueset.ValueSetExpansion"
)

ValueSetExpansionContainsType = create_fhir_type(
    "ValueSetExpansionContainsType",
    "fhir.resources.STU3.valueset.ValueSetExpansionContains",
)

ValueSetExpansionParameterType = create_fhir_type(
    "ValueSetExpansionParameterType",
    "fhir.resources.STU3.valueset.ValueSetExpansionParameter",
)

VisionPrescriptionType = create_fhir_type(
    "VisionPrescriptionType",
    "fhir.resources.STU3.visionprescription.VisionPrescription",
)

VisionPrescriptionDispenseType = create_fhir_type(
    "VisionPrescriptionDispenseType",
    "fhir.resources.STU3.visionprescription.VisionPrescriptionDispense",
)

__all__ = [
    "BooleanType",
    "StringType",
    "Base64BinaryType",
    "CodeType",
    "IdType",
    "IntegerType",
    "Integer64Type",
    "DecimalType",
    "UnsignedIntType",
    "PositiveIntType",
    "CanonicalType",
    "UriType",
    "OidType",
    "UuidType",
    "UrlType",
    "MarkdownType",
    "XhtmlType",
    "DateType",
    "DateTimeType",
    "InstantType",
    "TimeType",
    "FHIRPrimitiveExtensionType",
    "AccountType",
    "AccountCoverageType",
    "AccountGuarantorType",
    "ActivityDefinitionType",
    "ActivityDefinitionDynamicValueType",
    "ActivityDefinitionParticipantType",
    "AddressType",
    "AdverseEventType",
    "AdverseEventSuspectEntityType",
    "AgeType",
    "AllergyIntoleranceType",
    "AllergyIntoleranceReactionType",
    "AnnotationType",
    "AppointmentType",
    "AppointmentParticipantType",
    "AppointmentResponseType",
    "AttachmentType",
    "AuditEventType",
    "AuditEventAgentType",
    "AuditEventAgentNetworkType",
    "AuditEventEntityType",
    "AuditEventEntityDetailType",
    "AuditEventSourceType",
    "BackboneElementType",
    "BasicType",
    "BinaryType",
    "BodySiteType",
    "BundleType",
    "BundleEntryType",
    "BundleEntryRequestType",
    "BundleEntryResponseType",
    "BundleEntrySearchType",
    "BundleLinkType",
    "CapabilityStatementType",
    "CapabilityStatementDocumentType",
    "CapabilityStatementImplementationType",
    "CapabilityStatementMessagingType",
    "CapabilityStatementMessagingEndpointType",
    "CapabilityStatementMessagingEventType",
    "CapabilityStatementMessagingSupportedMessageType",
    "CapabilityStatementRestType",
    "CapabilityStatementRestInteractionType",
    "CapabilityStatementRestOperationType",
    "CapabilityStatementRestResourceType",
    "CapabilityStatementRestResourceInteractionType",
    "CapabilityStatementRestResourceSearchParamType",
    "CapabilityStatementRestSecurityType",
    "CapabilityStatementRestSecurityCertificateType",
    "CapabilityStatementSoftwareType",
    "CarePlanType",
    "CarePlanActivityType",
    "CarePlanActivityDetailType",
    "CareTeamType",
    "CareTeamParticipantType",
    "ChargeItemType",
    "ChargeItemParticipantType",
    "ClaimType",
    "ClaimAccidentType",
    "ClaimCareTeamType",
    "ClaimDiagnosisType",
    "ClaimInformationType",
    "ClaimInsuranceType",
    "ClaimItemType",
    "ClaimItemDetailType",
    "ClaimItemDetailSubDetailType",
    "ClaimPayeeType",
    "ClaimProcedureType",
    "ClaimRelatedType",
    "ClaimResponseType",
    "ClaimResponseAddItemType",
    "ClaimResponseAddItemDetailType",
    "ClaimResponseErrorType",
    "ClaimResponseInsuranceType",
    "ClaimResponseItemType",
    "ClaimResponseItemAdjudicationType",
    "ClaimResponseItemDetailType",
    "ClaimResponseItemDetailSubDetailType",
    "ClaimResponsePaymentType",
    "ClaimResponseProcessNoteType",
    "ClinicalImpressionType",
    "ClinicalImpressionFindingType",
    "ClinicalImpressionInvestigationType",
    "CodeSystemType",
    "CodeSystemConceptType",
    "CodeSystemConceptDesignationType",
    "CodeSystemConceptPropertyType",
    "CodeSystemFilterType",
    "CodeSystemPropertyType",
    "CodeableConceptType",
    "CodingType",
    "CommunicationType",
    "CommunicationPayloadType",
    "CommunicationRequestType",
    "CommunicationRequestPayloadType",
    "CommunicationRequestRequesterType",
    "CompartmentDefinitionType",
    "CompartmentDefinitionResourceType",
    "CompositionType",
    "CompositionAttesterType",
    "CompositionEventType",
    "CompositionRelatesToType",
    "CompositionSectionType",
    "ConceptMapType",
    "ConceptMapGroupType",
    "ConceptMapGroupElementType",
    "ConceptMapGroupElementTargetType",
    "ConceptMapGroupElementTargetDependsOnType",
    "ConceptMapGroupUnmappedType",
    "ConditionType",
    "ConditionEvidenceType",
    "ConditionStageType",
    "ConsentType",
    "ConsentActorType",
    "ConsentDataType",
    "ConsentExceptType",
    "ConsentExceptActorType",
    "ConsentExceptDataType",
    "ConsentPolicyType",
    "ContactDetailType",
    "ContactPointType",
    "ContractType",
    "ContractAgentType",
    "ContractFriendlyType",
    "ContractLegalType",
    "ContractRuleType",
    "ContractSignerType",
    "ContractTermType",
    "ContractTermAgentType",
    "ContractTermValuedItemType",
    "ContractValuedItemType",
    "ContributorType",
    "CountType",
    "CoverageType",
    "CoverageGroupingType",
    "DataElementType",
    "DataElementMappingType",
    "DataRequirementType",
    "DataRequirementCodeFilterType",
    "DataRequirementDateFilterType",
    "DetectedIssueType",
    "DetectedIssueMitigationType",
    "DeviceType",
    "DeviceComponentType",
    "DeviceComponentProductionSpecificationType",
    "DeviceMetricType",
    "DeviceMetricCalibrationType",
    "DeviceRequestType",
    "DeviceRequestRequesterType",
    "DeviceUdiType",
    "DeviceUseStatementType",
    "DiagnosticReportType",
    "DiagnosticReportImageType",
    "DiagnosticReportPerformerType",
    "DistanceType",
    "DocumentManifestType",
    "DocumentManifestContentType",
    "DocumentManifestRelatedType",
    "DocumentReferenceType",
    "DocumentReferenceContentType",
    "DocumentReferenceContextType",
    "DocumentReferenceContextRelatedType",
    "DocumentReferenceRelatesToType",
    "DomainResourceType",
    "DosageType",
    "DurationType",
    "ElementType",
    "ElementDefinitionType",
    "ElementDefinitionBaseType",
    "ElementDefinitionBindingType",
    "ElementDefinitionConstraintType",
    "ElementDefinitionExampleType",
    "ElementDefinitionMappingType",
    "ElementDefinitionSlicingType",
    "ElementDefinitionSlicingDiscriminatorType",
    "ElementDefinitionTypeType",
    "EligibilityRequestType",
    "EligibilityResponseType",
    "EligibilityResponseErrorType",
    "EligibilityResponseInsuranceType",
    "EligibilityResponseInsuranceBenefitBalanceType",
    "EligibilityResponseInsuranceBenefitBalanceFinancialType",
    "EncounterType",
    "EncounterClassHistoryType",
    "EncounterDiagnosisType",
    "EncounterHospitalizationType",
    "EncounterLocationType",
    "EncounterParticipantType",
    "EncounterStatusHistoryType",
    "EndpointType",
    "EnrollmentRequestType",
    "EnrollmentResponseType",
    "EpisodeOfCareType",
    "EpisodeOfCareDiagnosisType",
    "EpisodeOfCareStatusHistoryType",
    "ExpansionProfileType",
    "ExpansionProfileDesignationType",
    "ExpansionProfileDesignationExcludeType",
    "ExpansionProfileDesignationExcludeDesignationType",
    "ExpansionProfileDesignationIncludeType",
    "ExpansionProfileDesignationIncludeDesignationType",
    "ExpansionProfileExcludedSystemType",
    "ExpansionProfileFixedVersionType",
    "ExplanationOfBenefitType",
    "ExplanationOfBenefitAccidentType",
    "ExplanationOfBenefitAddItemType",
    "ExplanationOfBenefitAddItemDetailType",
    "ExplanationOfBenefitBenefitBalanceType",
    "ExplanationOfBenefitBenefitBalanceFinancialType",
    "ExplanationOfBenefitCareTeamType",
    "ExplanationOfBenefitDiagnosisType",
    "ExplanationOfBenefitInformationType",
    "ExplanationOfBenefitInsuranceType",
    "ExplanationOfBenefitItemType",
    "ExplanationOfBenefitItemAdjudicationType",
    "ExplanationOfBenefitItemDetailType",
    "ExplanationOfBenefitItemDetailSubDetailType",
    "ExplanationOfBenefitPayeeType",
    "ExplanationOfBenefitPaymentType",
    "ExplanationOfBenefitProcedureType",
    "ExplanationOfBenefitProcessNoteType",
    "ExplanationOfBenefitRelatedType",
    "ExtensionType",
    "FamilyMemberHistoryType",
    "FamilyMemberHistoryConditionType",
    "FlagType",
    "GoalType",
    "GoalTargetType",
    "GraphDefinitionType",
    "GraphDefinitionLinkType",
    "GraphDefinitionLinkTargetType",
    "GraphDefinitionLinkTargetCompartmentType",
    "GroupType",
    "GroupCharacteristicType",
    "GroupMemberType",
    "GuidanceResponseType",
    "HealthcareServiceType",
    "HealthcareServiceAvailableTimeType",
    "HealthcareServiceNotAvailableType",
    "HumanNameType",
    "IdentifierType",
    "ImagingManifestType",
    "ImagingManifestStudyType",
    "ImagingManifestStudySeriesType",
    "ImagingManifestStudySeriesInstanceType",
    "ImagingStudyType",
    "ImagingStudySeriesType",
    "ImagingStudySeriesInstanceType",
    "ImmunizationType",
    "ImmunizationExplanationType",
    "ImmunizationPractitionerType",
    "ImmunizationReactionType",
    "ImmunizationRecommendationType",
    "ImmunizationRecommendationRecommendationType",
    "ImmunizationRecommendationRecommendationDateCriterionType",
    "ImmunizationRecommendationRecommendationProtocolType",
    "ImmunizationVaccinationProtocolType",
    "ImplementationGuideType",
    "ImplementationGuideDependencyType",
    "ImplementationGuideGlobalType",
    "ImplementationGuidePackageType",
    "ImplementationGuidePackageResourceType",
    "ImplementationGuidePageType",
    "LibraryType",
    "LinkageType",
    "LinkageItemType",
    "ListType",
    "ListEntryType",
    "LocationType",
    "LocationPositionType",
    "MeasureType",
    "MeasureGroupType",
    "MeasureGroupPopulationType",
    "MeasureGroupStratifierType",
    "MeasureReportType",
    "MeasureReportGroupType",
    "MeasureReportGroupPopulationType",
    "MeasureReportGroupStratifierType",
    "MeasureReportGroupStratifierStratumType",
    "MeasureReportGroupStratifierStratumPopulationType",
    "MeasureSupplementalDataType",
    "MediaType",
    "MedicationType",
    "MedicationAdministrationType",
    "MedicationAdministrationDosageType",
    "MedicationAdministrationPerformerType",
    "MedicationDispenseType",
    "MedicationDispensePerformerType",
    "MedicationDispenseSubstitutionType",
    "MedicationIngredientType",
    "MedicationPackageType",
    "MedicationPackageBatchType",
    "MedicationPackageContentType",
    "MedicationRequestType",
    "MedicationRequestDispenseRequestType",
    "MedicationRequestRequesterType",
    "MedicationRequestSubstitutionType",
    "MedicationStatementType",
    "MessageDefinitionType",
    "MessageDefinitionAllowedResponseType",
    "MessageDefinitionFocusType",
    "MessageHeaderType",
    "MessageHeaderDestinationType",
    "MessageHeaderResponseType",
    "MessageHeaderSourceType",
    "MetaType",
    "MetadataResourceType",
    "MoneyType",
    "NamingSystemType",
    "NamingSystemUniqueIdType",
    "NarrativeType",
    "NutritionOrderType",
    "NutritionOrderEnteralFormulaType",
    "NutritionOrderEnteralFormulaAdministrationType",
    "NutritionOrderOralDietType",
    "NutritionOrderOralDietNutrientType",
    "NutritionOrderOralDietTextureType",
    "NutritionOrderSupplementType",
    "ObservationType",
    "ObservationComponentType",
    "ObservationReferenceRangeType",
    "ObservationRelatedType",
    "OperationDefinitionType",
    "OperationDefinitionOverloadType",
    "OperationDefinitionParameterType",
    "OperationDefinitionParameterBindingType",
    "OperationOutcomeType",
    "OperationOutcomeIssueType",
    "OrganizationType",
    "OrganizationContactType",
    "ParameterDefinitionType",
    "ParametersType",
    "ParametersParameterType",
    "PatientType",
    "PatientAnimalType",
    "PatientCommunicationType",
    "PatientContactType",
    "PatientLinkType",
    "PaymentNoticeType",
    "PaymentReconciliationType",
    "PaymentReconciliationDetailType",
    "PaymentReconciliationProcessNoteType",
    "PeriodType",
    "PersonType",
    "PersonLinkType",
    "PlanDefinitionType",
    "PlanDefinitionActionType",
    "PlanDefinitionActionConditionType",
    "PlanDefinitionActionDynamicValueType",
    "PlanDefinitionActionParticipantType",
    "PlanDefinitionActionRelatedActionType",
    "PlanDefinitionGoalType",
    "PlanDefinitionGoalTargetType",
    "PractitionerType",
    "PractitionerQualificationType",
    "PractitionerRoleType",
    "PractitionerRoleAvailableTimeType",
    "PractitionerRoleNotAvailableType",
    "ProcedureType",
    "ProcedureFocalDeviceType",
    "ProcedurePerformerType",
    "ProcedureRequestType",
    "ProcedureRequestRequesterType",
    "ProcessRequestType",
    "ProcessRequestItemType",
    "ProcessResponseType",
    "ProcessResponseProcessNoteType",
    "ProvenanceType",
    "ProvenanceAgentType",
    "ProvenanceEntityType",
    "QuantityType",
    "QuestionnaireType",
    "QuestionnaireItemType",
    "QuestionnaireItemEnableWhenType",
    "QuestionnaireItemOptionType",
    "QuestionnaireResponseType",
    "QuestionnaireResponseItemType",
    "QuestionnaireResponseItemAnswerType",
    "RangeType",
    "RatioType",
    "ReferenceType",
    "ReferralRequestType",
    "ReferralRequestRequesterType",
    "RelatedArtifactType",
    "RelatedPersonType",
    "RequestGroupType",
    "RequestGroupActionType",
    "RequestGroupActionConditionType",
    "RequestGroupActionRelatedActionType",
    "ResearchStudyType",
    "ResearchStudyArmType",
    "ResearchSubjectType",
    "ResourceType",
    "RiskAssessmentType",
    "RiskAssessmentPredictionType",
    "SampledDataType",
    "ScheduleType",
    "SearchParameterType",
    "SearchParameterComponentType",
    "SequenceType",
    "SequenceQualityType",
    "SequenceReferenceSeqType",
    "SequenceRepositoryType",
    "SequenceVariantType",
    "ServiceDefinitionType",
    "SignatureType",
    "SlotType",
    "SpecimenType",
    "SpecimenCollectionType",
    "SpecimenContainerType",
    "SpecimenProcessingType",
    "StructureDefinitionType",
    "StructureDefinitionDifferentialType",
    "StructureDefinitionMappingType",
    "StructureDefinitionSnapshotType",
    "StructureMapType",
    "StructureMapGroupType",
    "StructureMapGroupInputType",
    "StructureMapGroupRuleType",
    "StructureMapGroupRuleDependentType",
    "StructureMapGroupRuleSourceType",
    "StructureMapGroupRuleTargetType",
    "StructureMapGroupRuleTargetParameterType",
    "StructureMapStructureType",
    "SubscriptionType",
    "SubscriptionChannelType",
    "SubstanceType",
    "SubstanceIngredientType",
    "SubstanceInstanceType",
    "SupplyDeliveryType",
    "SupplyDeliverySuppliedItemType",
    "SupplyRequestType",
    "SupplyRequestOrderedItemType",
    "SupplyRequestRequesterType",
    "TaskType",
    "TaskInputType",
    "TaskOutputType",
    "TaskRequesterType",
    "TaskRestrictionType",
    "TestReportType",
    "TestReportParticipantType",
    "TestReportSetupType",
    "TestReportSetupActionType",
    "TestReportSetupActionAssertType",
    "TestReportSetupActionOperationType",
    "TestReportTeardownType",
    "TestReportTeardownActionType",
    "TestReportTestType",
    "TestReportTestActionType",
    "TestScriptType",
    "TestScriptDestinationType",
    "TestScriptFixtureType",
    "TestScriptMetadataType",
    "TestScriptMetadataCapabilityType",
    "TestScriptMetadataLinkType",
    "TestScriptOriginType",
    "TestScriptRuleType",
    "TestScriptRuleParamType",
    "TestScriptRulesetType",
    "TestScriptRulesetRuleType",
    "TestScriptRulesetRuleParamType",
    "TestScriptSetupType",
    "TestScriptSetupActionType",
    "TestScriptSetupActionAssertType",
    "TestScriptSetupActionAssertRuleType",
    "TestScriptSetupActionAssertRuleParamType",
    "TestScriptSetupActionAssertRulesetType",
    "TestScriptSetupActionAssertRulesetRuleType",
    "TestScriptSetupActionAssertRulesetRuleParamType",
    "TestScriptSetupActionOperationType",
    "TestScriptSetupActionOperationRequestHeaderType",
    "TestScriptTeardownType",
    "TestScriptTeardownActionType",
    "TestScriptTestType",
    "TestScriptTestActionType",
    "TestScriptVariableType",
    "TimingType",
    "TimingRepeatType",
    "TriggerDefinitionType",
    "UsageContextType",
    "ValueSetType",
    "ValueSetComposeType",
    "ValueSetComposeIncludeType",
    "ValueSetComposeIncludeConceptType",
    "ValueSetComposeIncludeConceptDesignationType",
    "ValueSetComposeIncludeFilterType",
    "ValueSetExpansionType",
    "ValueSetExpansionContainsType",
    "ValueSetExpansionParameterType",
    "VisionPrescriptionType",
    "VisionPrescriptionDispenseType",
]



# -*- coding: utf-8 -*-
"""
Profile: http://hl7.org/fhir/StructureDefinition/PractitionerRole
Release: R5
Version: 5.0.0
Build ID: 2aecd53
Last updated: 2023-03-26T15:21:02.749+11:00
"""
import typing

from pydantic import Field

from . import domainresource, fhirtypes


class PractitionerRole(domainresource.DomainResource):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    Roles/organizations the practitioner is associated with.
    A specific set of Roles/Locations/specialties/services that a practitioner
    may perform at an organization for a period of time.
    """

    __resource_type__ = "PractitionerRole"

    active: bool = Field(  # type: ignore
        None,
        alias="active",
        title="Whether this practitioner role record is in active use",
        description=(
            " Whether this practitioner role record is in active use. Some systems "
            "may use this property to mark non-active practitioners, such as those "
            "that are not currently employed."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    active__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_active", title="Extension field for ``active``."
    )

    availability: typing.List[fhirtypes.AvailabilityType] = Field(  # type: ignore
        None,
        alias="availability",
        title=(
            "Times the Practitioner is available at this location and/or healthcare"
            " service (including exceptions)"
        ),
        description=(
            "A collection of times the practitioner is available or performing this"
            " role at the location and/or healthcareservice."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    characteristic: typing.List[fhirtypes.CodeableConceptType] = Field(  # type: ignore
        None,
        alias="characteristic",
        title="Collection of characteristics (attributes)",
        description=None,
        json_schema_extra={
            "element_property": True,
        },
    )

    code: typing.List[fhirtypes.CodeableConceptType] = Field(  # type: ignore
        None,
        alias="code",
        title="Roles which this practitioner may perform",
        description=(
            "Roles which this practitioner is authorized to perform for the "
            "organization."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    communication: typing.List[fhirtypes.CodeableConceptType] = Field(  # type: ignore
        None,
        alias="communication",
        title=(
            "A language the practitioner (in this role) can use in patient "
            "communication"
        ),
        description=(
            "A language the practitioner can use in patient communication. The "
            "practitioner may know several languages (listed in "
            "practitioner.communication), however these are the languages that "
            "could be advertised in a directory for a patient to search."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    contact: typing.List[fhirtypes.ExtendedContactDetailType] = Field(  # type: ignore
        None,
        alias="contact",
        title="Official contact details relating to this PractitionerRole",
        description=(
            "The contact details of communication devices available relevant to the"
            " specific PractitionerRole. This can include addresses, phone numbers,"
            " fax numbers, mobile numbers, email addresses and web sites."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    endpoint: typing.List[fhirtypes.ReferenceType] = Field(  # type: ignore
        None,
        alias="endpoint",
        title="Endpoints for interacting with the practitioner in this role",
        description=(
            " Technical endpoints providing access to services operated for the "
            "practitioner with this role. Commonly used for locating scheduling "
            "services, or identifying where to send referrals electronically."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["Endpoint"],
        },
    )

    healthcareService: typing.List[fhirtypes.ReferenceType] = Field(  # type: ignore
        None,
        alias="healthcareService",
        title="Healthcare services provided for this role's Organization/Location(s)",
        description=(
            "The list of healthcare services that this worker provides for this "
            "role's Organization/Location(s)."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["HealthcareService"],
        },
    )

    identifier: typing.List[fhirtypes.IdentifierType] = Field(  # type: ignore
        None,
        alias="identifier",
        title="Identifiers for a role/location",
        description="Business Identifiers that are specific to a role/location.",
        json_schema_extra={
            "element_property": True,
        },
    )

    location: typing.List[fhirtypes.ReferenceType] = Field(  # type: ignore
        None,
        alias="location",
        title="Location(s) where the practitioner provides care",
        description="The location(s) at which this practitioner provides care.",
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["Location"],
        },
    )

    organization: fhirtypes.ReferenceType = Field(  # type: ignore
        None,
        alias="organization",
        title="Organization where the roles are available",
        description="The organization where the Practitioner performs the roles associated.",
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["Organization"],
        },
    )

    period: fhirtypes.PeriodType = Field(  # type: ignore
        None,
        alias="period",
        title=(
            "The period during which the practitioner is authorized to perform in "
            "these role(s)"
        ),
        description=(
            "The period during which the person is authorized to act as a "
            "practitioner in these role(s) for the organization."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    practitioner: fhirtypes.ReferenceType = Field(  # type: ignore
        None,
        alias="practitioner",
        title="Practitioner that provides services for the organization",
        description=(
            "Practitioner that is able to provide the defined services for the "
            "organization."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["Practitioner"],
        },
    )

    specialty: typing.List[fhirtypes.CodeableConceptType] = Field(  # type: ignore
        None,
        alias="specialty",
        title="Specific specialty of the practitioner",
        description=(
            "The specialty of a practitioner that describes the functional role "
            "they are practicing at a given organization or location."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``PractitionerRole`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "meta",
            "implicitRules",
            "language",
            "text",
            "contained",
            "extension",
            "modifierExtension",
            "identifier",
            "active",
            "period",
            "practitioner",
            "organization",
            "code",
            "specialty",
            "location",
            "healthcareService",
            "contact",
            "characteristic",
            "communication",
            "availability",
            "endpoint",
        ]



# -*- coding: utf-8 -*-
"""
Profile: http://hl7.org/fhir/StructureDefinition/ImagingManifest
Release: STU3
Version: 3.0.2
Revision: 11917
Last updated: 2019-10-24T11:53:00+11:00
"""
import typing

from pydantic import Field

from . import backboneelement, domainresource, fhirtypes


class ImagingManifest(domainresource.DomainResource):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    Key Object Selection.
    A text description of the DICOM SOP instances selected in the
    ImagingManifest; or the reason for, or significance of, the selection.
    """

    __resource_type__ = "ImagingManifest"

    author: fhirtypes.ReferenceType = Field(  # type: ignore
        None,
        alias="author",
        title="Author (human or machine)",
        description=(
            "Author of ImagingManifest. It can be a human author or a device which "
            "made the decision of the SOP instances selected. For example, a "
            "radiologist selected a set of imaging SOP instances to attach in a "
            "diagnostic report, and a CAD application may author a selection to "
            "describe SOP instances it used to generate a detection conclusion."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": [
                "Practitioner",
                "Device",
                "Organization",
                "Patient",
                "RelatedPerson",
            ],
        },
    )

    authoringTime: fhirtypes.DateTimeType = Field(  # type: ignore
        None,
        alias="authoringTime",
        title="Time when the selection of instances was made",
        description=(
            "Date and time when the selection of the referenced instances were "
            "made. It is (typically) different from the creation date of the "
            "selection resource, and from dates associated with the referenced "
            "instances (e.g. capture time of the referenced image)."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    authoringTime__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_authoringTime", title="Extension field for ``authoringTime``."
    )

    description: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="description",
        title="Description text",
        description=(
            "Free text narrative description of the ImagingManifest.   The value "
            "may be derived from the DICOM Standard Part 16, CID-7010 descriptions "
            "(e.g. Best in Set, Complete Study Content). Note that those values "
            "cover the wide range of uses of the DICOM Key Object Selection object,"
            " several of which are not supported by ImagingManifest. Specifically, "
            "there is no expected behavior associated with descriptions that "
            "suggest referenced images be removed or not used."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    description__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_description", title="Extension field for ``description``."
    )

    identifier: fhirtypes.IdentifierType = Field(  # type: ignore
        None,
        alias="identifier",
        title="SOP Instance UID",
        description=(
            "Unique identifier of the DICOM Key Object Selection (KOS) that this "
            "resource represents."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    patient: fhirtypes.ReferenceType = Field(  # type: ignore
        ...,
        alias="patient",
        title="Patient of the selected objects",
        description=(
            "A patient resource reference which is the patient subject of all DICOM"
            " SOP Instances in this ImagingManifest."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["Patient"],
        },
    )

    study: typing.List[fhirtypes.ImagingManifestStudyType] = Field(  # type: ignore
        ...,
        alias="study",
        title="Study identity of the selected instances",
        description=(
            "Study identity and locating information of the DICOM SOP instances in "
            "the selection."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``ImagingManifest`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "meta",
            "implicitRules",
            "language",
            "text",
            "contained",
            "extension",
            "modifierExtension",
            "identifier",
            "patient",
            "authoringTime",
            "author",
            "description",
            "study",
        ]


class ImagingManifestStudy(backboneelement.BackboneElement):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    Study identity of the selected instances.
    Study identity and locating information of the DICOM SOP instances in the
    selection.
    """

    __resource_type__ = "ImagingManifestStudy"

    endpoint: typing.List[fhirtypes.ReferenceType] = Field(  # type: ignore
        None,
        alias="endpoint",
        title="Study access service endpoint",
        description=(
            "The network service providing access (e.g., query, view, or retrieval)"
            " for the study. See implementation notes for information about using "
            "DICOM endpoints. A study-level endpoint applies to each series in the "
            "study, unless overridden by a series-level endpoint with the same "
            "Endpoint.type."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["Endpoint"],
        },
    )

    imagingStudy: fhirtypes.ReferenceType = Field(  # type: ignore
        None,
        alias="imagingStudy",
        title="Reference to ImagingStudy",
        description="Reference to the Imaging Study in FHIR form.",
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["ImagingStudy"],
        },
    )

    series: typing.List[fhirtypes.ImagingManifestStudySeriesType] = Field(  # type: ignore
        ...,
        alias="series",
        title="Series identity of the selected instances",
        description=(
            "Series identity and locating information of the DICOM SOP instances in"
            " the selection."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )

    uid: fhirtypes.OidType = Field(  # type: ignore
        None,
        alias="uid",
        title="Study instance UID",
        description="Study instance UID of the SOP instances in the selection.",
        json_schema_extra={
            "element_property": True,
            "element_required": True,
        },
    )
    uid__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_uid", title="Extension field for ``uid``."
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``ImagingManifestStudy`` according specification,
        with preserving original sequence order.
        """
        return [
            "id",
            "extension",
            "modifierExtension",
            "uid",
            "imagingStudy",
            "endpoint",
            "series",
        ]

    def get_required_fields(self) -> typing.List[typing.Tuple[str, str]]:
        """https://www.hl7.org/fhir/extensibility.html#Special-Case
        In some cases, implementers might find that they do not have appropriate data for
        an element with minimum cardinality = 1. In this case, the element must be present,
        but unless the resource or a profile on it has made the actual value of the primitive
        data type mandatory, it is possible to provide an extension that explains why
        the primitive value is not present.
        """
        required_fields = [("uid", "uid__ext")]
        return required_fields


class ImagingManifestStudySeries(backboneelement.BackboneElement):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    Series identity of the selected instances.
    Series identity and locating information of the DICOM SOP instances in the
    selection.
    """

    __resource_type__ = "ImagingManifestStudySeries"

    endpoint: typing.List[fhirtypes.ReferenceType] = Field(  # type: ignore
        None,
        alias="endpoint",
        title="Series access endpoint",
        description=(
            "The network service providing access (e.g., query, view, or retrieval)"
            " for this series. See implementation notes for information about using"
            " DICOM endpoints. A series-level endpoint, if present, has precedence "
            "over a study-level endpoint with the same Endpoint.type."
        ),
        json_schema_extra={
            "element_property": True,
            # note: Listed Resource Type(s) should be allowed as Reference.
            "enum_reference_types": ["Endpoint"],
        },
    )

    instance: typing.List[fhirtypes.ImagingManifestStudySeriesInstanceType] = Field(  # type: ignore
        ...,
        alias="instance",
        title="The selected instance",
        description="Identity and locating information of the selected DICOM SOP instances.",
        json_schema_extra={
            "element_property": True,
        },
    )

    uid: fhirtypes.OidType = Field(  # type: ignore
        None,
        alias="uid",
        title="Series instance UID",
        description="Series instance UID of the SOP instances in the selection.",
        json_schema_extra={
            "element_property": True,
            "element_required": True,
        },
    )
    uid__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_uid", title="Extension field for ``uid``."
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``ImagingManifestStudySeries`` according specification,
        with preserving original sequence order.
        """
        return ["id", "extension", "modifierExtension", "uid", "endpoint", "instance"]

    def get_required_fields(self) -> typing.List[typing.Tuple[str, str]]:
        """https://www.hl7.org/fhir/extensibility.html#Special-Case
        In some cases, implementers might find that they do not have appropriate data for
        an element with minimum cardinality = 1. In this case, the element must be present,
        but unless the resource or a profile on it has made the actual value of the primitive
        data type mandatory, it is possible to provide an extension that explains why
        the primitive value is not present.
        """
        required_fields = [("uid", "uid__ext")]
        return required_fields


class ImagingManifestStudySeriesInstance(backboneelement.BackboneElement):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    The selected instance.
    Identity and locating information of the selected DICOM SOP instances.
    """

    __resource_type__ = "ImagingManifestStudySeriesInstance"

    sopClass: fhirtypes.OidType = Field(  # type: ignore
        None,
        alias="sopClass",
        title="SOP class UID of instance",
        description="SOP class UID of the selected instance.",
        json_schema_extra={
            "element_property": True,
            "element_required": True,
        },
    )
    sopClass__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_sopClass", title="Extension field for ``sopClass``."
    )

    uid: fhirtypes.OidType = Field(  # type: ignore
        None,
        alias="uid",
        title="Selected instance UID",
        description="SOP Instance UID of the selected instance.",
        json_schema_extra={
            "element_property": True,
            "element_required": True,
        },
    )
    uid__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_uid", title="Extension field for ``uid``."
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``ImagingManifestStudySeriesInstance`` according specification,
        with preserving original sequence order.
        """
        return ["id", "extension", "modifierExtension", "sopClass", "uid"]

    def get_required_fields(self) -> typing.List[typing.Tuple[str, str]]:
        """https://www.hl7.org/fhir/extensibility.html#Special-Case
        In some cases, implementers might find that they do not have appropriate data for
        an element with minimum cardinality = 1. In this case, the element must be present,
        but unless the resource or a profile on it has made the actual value of the primitive
        data type mandatory, it is possible to provide an extension that explains why
        the primitive value is not present.
        """
        required_fields = [("sopClass", "sopClass__ext"), ("uid", "uid__ext")]
        return required_fields



# -*- coding: utf-8 -*-
"""
Profile: http://hl7.org/fhir/StructureDefinition/SimpleQuantity
Release: R5
Version: 5.0.0
Build ID: 2aecd53
Last updated: 2023-03-26T15:21:02.749+11:00
"""
from pydantic import Field

from . import datatype, fhirtypes


class Quantity(datatype.DataType):
    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
    Resource StructureDefinition, instead used to enable Extensibility feature
    for FHIR Primitive Data Types.

    A measured or measurable amount.
    A measured amount (or an amount that can potentially be measured). Note
    that measured amounts include amounts that are not precisely quantified,
    including amounts involving arbitrary units and floating currencies.
    """

    __resource_type__ = "Quantity"

    code: fhirtypes.CodeType = Field(  # type: ignore
        None,
        alias="code",
        title="Coded form of the unit",
        description=(
            "A computer processable form of the unit in some unit representation "
            "system."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    code__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_code", title="Extension field for ``code``."
    )

    comparator: fhirtypes.CodeType = Field(  # type: ignore
        None,
        alias="comparator",
        title="< | <= | >= | > | ad - how to understand the value",
        description=(
            "How the value should be understood and represented - whether the "
            "actual value is greater or less than the stated value due to "
            'measurement issues; e.g. if the comparator is "<" , then the real '
            "value is < stated value."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    comparator__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_comparator", title="Extension field for ``comparator``."
    )

    system: fhirtypes.UriType = Field(  # type: ignore
        None,
        alias="system",
        title="System that defines coded unit form",
        description=(
            "The identification of the system that provides the coded form of the "
            "unit."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    system__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_system", title="Extension field for ``system``."
    )

    unit: fhirtypes.StringType = Field(  # type: ignore
        None,
        alias="unit",
        title="Unit representation",
        description="A human-readable form of the unit.",
        json_schema_extra={
            "element_property": True,
        },
    )
    unit__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_unit", title="Extension field for ``unit``."
    )

    value: fhirtypes.DecimalType = Field(  # type: ignore
        None,
        alias="value",
        title="Numerical value (with implicit precision)",
        description=(
            "The value of the measured amount. The value includes an implicit "
            "precision in the presentation of the value."
        ),
        json_schema_extra={
            "element_property": True,
        },
    )
    value__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(  # type: ignore
        None, alias="_value", title="Extension field for ``value``."
    )

    @classmethod
    def elements_sequence(cls):
        """returning all elements names from
        ``Quantity`` according specification,
        with preserving original sequence order.
        """
        return ["id", "extension", "value", "comparator", "unit", "system", "code"]
